@@ -67,7 +67,7 @@ protected:
   const VVVdouble* array1_, * array2_;
   const SubstitutionModel* model_;
   const DiscreteDistribution* rDist_;
-  unsigned int nbStates_, nbClasses_;
+  size_t nbStates_, nbClasses_;
   VVVdouble pxy_;
   double lnL_;
   std::vector<unsigned int> weights_;
@@ -85,8 +85,7 @@ public:
     lnL_(log(0.)),
     weights_(weights)
   {
-    Parameter p("BrLen", 1, 0);
-    addParameter_(p);
+    addParameter_(new Parameter("BrLen", 1, 0));
   }
 
   BranchLikelihood(const BranchLikelihood& bl) :
