@@ -75,7 +75,7 @@ PseudoNewtonOptimizer::PseudoNewtonOptimizer(DerivableSecondOrder* function) :
   n_(0),
   params_(),
   maxCorrection_(10),
-  useCJ_(true)
+  useCG_(true)
 {
   setDefaultStopCondition_(new FunctionStopCondition(this));
   setStopCondition(*getDefaultStopCondition());
@@ -101,7 +101,7 @@ double PseudoNewtonOptimizer::doStep() throw (Exception)
   // Compute derivative at current point:
   std::vector<double> movements(n_);
   ParameterList newPoint = getParameters();
-  for (unsigned int i = 0; i < n_; i++)
+  for (size_t i = 0; i < n_; i++)
   {
     double  firstOrderDerivative = getFunction()->getFirstOrderDerivative(params_[i]);
     double secondOrderDerivative = getFunction()->getSecondOrderDerivative(params_[i]);
@@ -129,17 +129,17 @@ double PseudoNewtonOptimizer::doStep() throw (Exception)
     movements[i] = getParameters()[i].getValue() - newPoint[i].getValue(); 
   }
   newValue = getFunction()->f(newPoint);
-  
+
   // Check newValue:
   unsigned int count = 0;
-  while ((count < maxCorrection_) && (newValue > currentValue_ + getStopCondition()->getTolerance())) {
+  while ((count < maxCorrection_) && ((newValue > currentValue_ + getStopCondition()->getTolerance()) || std::isnan(newValue))) {
     //Restore previous point (all parameters in case of global constraint):
     if ((count==0) && updateParameters()) getFunction()->setParameters(*bckPoint);
-
-    if (!(useCJ_ && (count==3))){
+    
+    if (!(useCG_ && (count==3))){
       printMessage("!!! Function at new point is greater than at current point: " + TextTools::toString(newValue) + ">" + TextTools::toString(currentValue_) + ". Applying Felsenstein-Churchill correction: " + TextTools::toString(count));
         
-      for (unsigned int i = 0; i < movements.size(); i++) {
+      for (size_t i = 0; i < movements.size(); i++) {
         movements[i] = movements[i] / 2;
         newPoint[i].setValue(getParameters()[i].getValue() - movements[i]);
       }
@@ -153,7 +153,7 @@ double PseudoNewtonOptimizer::doStep() throw (Exception)
       opt.setConstraintPolicy(getConstraintPolicy());
       opt.setProfiler(getProfiler());
       opt.setMessageHandler(getMessageHandler());
-      opt.setVerbose(getVerbose());
+      opt.setVerbose(0);
       double tol = std::max(getStopCondition()->getCurrentTolerance() / 2., getStopCondition()->getTolerance());
       opt.getStopCondition()->setTolerance(tol);
       opt.setMaximumNumberOfEvaluations(nbEvalMax_);
@@ -171,19 +171,23 @@ double PseudoNewtonOptimizer::doStep() throw (Exception)
     count++;
   }
   
-  if (newValue > currentValue_ + getStopCondition()->getTolerance())
-    printMessage("PseudoNewtonOptimizer::doStep. Convergence could not be reached!");
-  
-  //getFunction()->enableFirstOrderDerivatives(true);
-  getFunction()->enableSecondOrderDerivatives(true);
-  getFunction()->setParameters(newPoint); //Compute derivatives for this point
-
-  previousPoint_ = getParameters();
-  previousValue_ = currentValue_;
-  getParameters_() = newPoint;
+  if (newValue > currentValue_ + getStopCondition()->getTolerance()){
+    printMessage("PseudoNewtonOptimizer::doStep. Value could not be ameliorated!");
+    newValue = currentValue_;
+  }
+  else  {
+    //getFunction()->enableFirstOrderDerivatives(true);
+    getFunction()->enableSecondOrderDerivatives(true);
+    getFunction()->setParameters(newPoint); //Compute derivatives for this point
+    
+    previousPoint_ = getParameters();
+    previousValue_ = currentValue_;
+    getParameters_() = newPoint;
+  }
 
   if (updateParameters()) delete bckPoint;
   return newValue;
+  
 }
 
 /**************************************************************************/
