@@ -5,7 +5,7 @@
 //
 
 /*
-   Copyright or © or Copr. CNRS, (November 16, 2004)
+   Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)
 
    This software is a computer program whose purpose is to provide classes
    for phylogenetic data analysis.
@@ -152,7 +152,7 @@ void RHomogeneousTreeLikelihood::setData(const SiteContainer& sites) throw (Exce
 double RHomogeneousTreeLikelihood::getLikelihood() const
 {
   double l = 1.;
-  for (unsigned int i = 0; i < nbSites_; i++)
+  for (size_t i = 0; i < nbSites_; i++)
   {
     l *= getLikelihoodForASite(i);
   }
@@ -165,12 +165,12 @@ double RHomogeneousTreeLikelihood::getLogLikelihood() const
 {
   double ll = 0;
   vector<double> la(nbSites_);
-  for (unsigned int i = 0; i < nbSites_; i++)
+  for (size_t i = 0; i < nbSites_; i++)
   {
     la[i] = getLogLikelihoodForASite(i);
   }
   sort(la.begin(), la.end());
-  for (unsigned int i = nbSites_; i > 0; i--)
+  for (size_t i = nbSites_; i > 0; i--)
   {
     ll += la[i - 1];
   }
@@ -179,10 +179,10 @@ double RHomogeneousTreeLikelihood::getLogLikelihood() const
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getLikelihoodForASite(unsigned int site) const
+double RHomogeneousTreeLikelihood::getLikelihoodForASite(size_t site) const
 {
   double l = 0;
-  for (unsigned int i = 0; i < nbClasses_; i++)
+  for (size_t i = 0; i < nbClasses_; i++)
   {
     l += getLikelihoodForASiteForARateClass(site, i) * rateDistribution_->getProbability(i);
   }
@@ -191,38 +191,39 @@ double RHomogeneousTreeLikelihood::getLikelihoodForASite(unsigned int site) cons
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getLogLikelihoodForASite(unsigned int site) const
+double RHomogeneousTreeLikelihood::getLogLikelihoodForASite(size_t site) const
 {
   double l = 0;
-  for (unsigned int i = 0; i < nbClasses_; i++)
+  for (size_t i = 0; i < nbClasses_; i++)
   {
-    l += getLikelihoodForASiteForARateClass(site, i) * rateDistribution_->getProbability(i);
+    double li = getLikelihoodForASiteForARateClass(site, i) * rateDistribution_->getProbability(i);
+    if (li > 0) l+= li; //Corrects for numerical instabilities leading to slightly negative likelihoods
   }
-  //if(l <= 0.) cerr << "WARNING!!! Negative likelihood." << endl;
-  if (l < 0) l = 0; //May happen because of numerical errors.
   return log(l);
 }
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getLikelihoodForASiteForARateClass(unsigned int site, unsigned int rateClass) const
+double RHomogeneousTreeLikelihood::getLikelihoodForASiteForARateClass(size_t site, size_t rateClass) const
 {
   double l = 0;
   Vdouble* la = &likelihoodData_->getLikelihoodArray(tree_->getRootNode()->getId())[likelihoodData_->getRootArrayPosition(site)][rateClass];
-  for (unsigned int i = 0; i < nbStates_; i++)
+  for (size_t i = 0; i < nbStates_; i++)
   {
-    l += (*la)[i] * rootFreqs_[i];
+    //cout << (*la)[i] << "\t" << rootFreqs_[i] << endl;
+    double li = (*la)[i] * rootFreqs_[i];
+    if (li > 0) l+= li; //Corrects for numerical instabilities leading to slightly negative likelihoods
   }
   return l;
 }
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getLogLikelihoodForASiteForARateClass(unsigned int site, unsigned int rateClass) const
+double RHomogeneousTreeLikelihood::getLogLikelihoodForASiteForARateClass(size_t site, size_t rateClass) const
 {
   double l = 0;
   Vdouble* la = &likelihoodData_->getLikelihoodArray(tree_->getRootNode()->getId())[likelihoodData_->getRootArrayPosition(site)][rateClass];
-  for (unsigned int i = 0; i < nbStates_; i++)
+  for (size_t i = 0; i < nbStates_; i++)
   {
     l += (*la)[i] * rootFreqs_[i];
   }
@@ -232,14 +233,14 @@ double RHomogeneousTreeLikelihood::getLogLikelihoodForASiteForARateClass(unsigne
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getLikelihoodForASiteForARateClassForAState(unsigned int site, unsigned int rateClass, int state) const
+double RHomogeneousTreeLikelihood::getLikelihoodForASiteForARateClassForAState(size_t site, size_t rateClass, int state) const
 {
   return likelihoodData_->getLikelihoodArray(tree_->getRootNode()->getId())[likelihoodData_->getRootArrayPosition(site)][rateClass][state];
 }
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getLogLikelihoodForASiteForARateClassForAState(unsigned int site, unsigned int rateClass, int state) const
+double RHomogeneousTreeLikelihood::getLogLikelihoodForASiteForARateClassForAState(size_t site, size_t rateClass, int state) const
 {
   return log(likelihoodData_->getLikelihoodArray(tree_->getRootNode()->getId())[likelihoodData_->getRootArrayPosition(site)][rateClass][state]);
 }
@@ -267,13 +268,13 @@ void RHomogeneousTreeLikelihood::fireParameterChanged(const ParameterList& param
   else if (params.size() > 0)
   {
     //We may save some computations:
-    for (unsigned int i = 0; i < params.size(); i++)
+    for (size_t i = 0; i < params.size(); i++)
     {
       string s = params[i].getName();
       if (s.substr(0, 5) == "BrLen")
       {
         //Branch length parameter:
-        computeTransitionProbabilitiesForNode(nodes_[TextTools::to<unsigned int>(s.substr(5))]);
+        computeTransitionProbabilitiesForNode(nodes_[TextTools::to<size_t>(s.substr(5))]);
       }
     }
     rootFreqs_ = model_->getFrequencies();
@@ -298,12 +299,12 @@ throw (Exception)
 ******************************************************************************/
 
 double RHomogeneousTreeLikelihood::getDLikelihoodForASiteForARateClass(
-  unsigned int site,
-  unsigned int rateClass) const
+  size_t site,
+  size_t rateClass) const
 {
   double dl = 0;
   Vdouble* dla = &likelihoodData_->getDLikelihoodArray(tree_->getRootNode()->getId())[likelihoodData_->getRootArrayPosition(site)][rateClass];
-  for (unsigned int i = 0; i < nbStates_; i++)
+  for (size_t i = 0; i < nbStates_; i++)
   {
     dl += (*dla)[i] * rootFreqs_[i];
   }
@@ -312,11 +313,11 @@ double RHomogeneousTreeLikelihood::getDLikelihoodForASiteForARateClass(
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getDLikelihoodForASite(unsigned int site) const
+double RHomogeneousTreeLikelihood::getDLikelihoodForASite(size_t site) const
 {
   // Derivative of the sum is the sum of derivatives:
   double dl = 0;
-  for (unsigned int i = 0; i < nbClasses_; i++)
+  for (size_t i = 0; i < nbClasses_; i++)
   {
     dl += getDLikelihoodForASiteForARateClass(site, i) * rateDistribution_->getProbability(i);
   }
@@ -325,7 +326,7 @@ double RHomogeneousTreeLikelihood::getDLikelihoodForASite(unsigned int site) con
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getDLogLikelihoodForASite(unsigned int site) const
+double RHomogeneousTreeLikelihood::getDLogLikelihoodForASite(size_t site) const
 {
   // d(f(g(x)))/dx = dg(x)/dx . df(g(x))/dg :
   return getDLikelihoodForASite(site) / getLikelihoodForASite(site);
@@ -337,7 +338,7 @@ double RHomogeneousTreeLikelihood::getDLogLikelihood() const
 {
   // Derivative of the sum is the sum of derivatives:
   double dl = 0;
-  for (unsigned int i = 0; i < nbSites_; i++)
+  for (size_t i = 0; i < nbSites_; i++)
   {
     dl += getDLogLikelihoodForASite(i);
   }
@@ -369,52 +370,52 @@ throw (Exception)
 void RHomogeneousTreeLikelihood::computeTreeDLikelihood(const string& variable)
 {
   // Get the node with the branch whose length must be derivated:
-  unsigned int brI = TextTools::to<unsigned int>(variable.substr(5));
+  size_t brI = TextTools::to<size_t>(variable.substr(5));
   const Node* branch = nodes_[brI];
   const Node* father = branch->getFather();
   VVVdouble* _dLikelihoods_father = &likelihoodData_->getDLikelihoodArray(father->getId());
 
   // Compute dLikelihoods array for the father node.
   // Fist initialize to 1:
-  unsigned int nbSites  = _dLikelihoods_father->size();
-  for (unsigned int i = 0; i < nbSites; i++)
+  size_t nbSites  = _dLikelihoods_father->size();
+  for (size_t i = 0; i < nbSites; i++)
   {
     VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-    for (unsigned int c = 0; c < nbClasses_; c++)
+    for (size_t c = 0; c < nbClasses_; c++)
     {
       Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
-      for (unsigned int s = 0; s < nbStates_; s++)
+      for (size_t s = 0; s < nbStates_; s++)
       {
         (*_dLikelihoods_father_i_c)[s] = 1.;
       }
     }
   }
 
-  unsigned int nbNodes = father->getNumberOfSons();
-  for (unsigned int l = 0; l < nbNodes; l++)
+  size_t nbNodes = father->getNumberOfSons();
+  for (size_t l = 0; l < nbNodes; l++)
   {
     const Node* son = father->getSon(l);
 
-    vector<unsigned int> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
+    vector<size_t> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
     VVVdouble* _likelihoods_son = &likelihoodData_->getLikelihoodArray(son->getId());
 
     if (son == branch)
     {
       VVVdouble* dpxy__son = &dpxy_[son->getId()];
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _likelihoods_son_i = &(*_likelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _likelihoods_son_i_c = &(*_likelihoods_son_i)[c];
           Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
           VVdouble* dpxy__son_c = &(*dpxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double dl = 0;
             Vdouble* dpxy__son_c_x = &(*dpxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               dl += (*dpxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
             }
@@ -426,20 +427,20 @@ void RHomogeneousTreeLikelihood::computeTreeDLikelihood(const string& variable)
     else
     {
       VVVdouble* pxy__son = &pxy_[son->getId()];
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _likelihoods_son_i = &(*_likelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _likelihoods_son_i_c = &(*_likelihoods_son_i)[c];
           Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
           VVdouble* pxy__son_c = &(*pxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double dl = 0;
             Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               dl += (*pxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
             }
@@ -466,45 +467,45 @@ void RHomogeneousTreeLikelihood::computeDownSubtreeDLikelihood(const Node* node)
   // Compute dLikelihoods array for the father node.
   // Fist initialize to 1:
   VVVdouble* _dLikelihoods_father = &likelihoodData_->getDLikelihoodArray(father->getId());
-  unsigned int nbSites  = _dLikelihoods_father->size();
-  for (unsigned int i = 0; i < nbSites; i++)
+  size_t nbSites  = _dLikelihoods_father->size();
+  for (size_t i = 0; i < nbSites; i++)
   {
     VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-    for (unsigned int c = 0; c < nbClasses_; c++)
+    for (size_t c = 0; c < nbClasses_; c++)
     {
       Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
-      for (unsigned int s = 0; s < nbStates_; s++)
+      for (size_t s = 0; s < nbStates_; s++)
       {
         (*_dLikelihoods_father_i_c)[s] = 1.;
       }
     }
   }
 
-  unsigned int nbNodes = father->getNumberOfSons();
-  for (unsigned int l = 0; l < nbNodes; l++)
+  size_t nbNodes = father->getNumberOfSons();
+  for (size_t l = 0; l < nbNodes; l++)
   {
     const Node* son = father->getSon(l);
 
     VVVdouble* pxy__son = &pxy_[son->getId()];
-    vector<unsigned int> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
+    vector<size_t> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
 
     if (son == node)
     {
       VVVdouble* _dLikelihoods_son = &likelihoodData_->getDLikelihoodArray(son->getId());
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _dLikelihoods_son_i = &(*_dLikelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _dLikelihoods_son_i_c = &(*_dLikelihoods_son_i)[c];
           Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
           VVdouble* pxy__son_c = &(*pxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double dl = 0;
             Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               dl += (*pxy__son_c_x)[y] * (*_dLikelihoods_son_i_c)[y];
             }
@@ -516,20 +517,20 @@ void RHomogeneousTreeLikelihood::computeDownSubtreeDLikelihood(const Node* node)
     else
     {
       VVVdouble* _likelihoods_son = &likelihoodData_->getLikelihoodArray(son->getId());
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _likelihoods_son_i = &(*_likelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _likelihoods_son_i_c = &(*_likelihoods_son_i)[c];
           Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
           VVdouble* pxy__son_c = &(*pxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double dl = 0;
             Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               dl += (*pxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
             }
@@ -549,12 +550,12 @@ void RHomogeneousTreeLikelihood::computeDownSubtreeDLikelihood(const Node* node)
 ******************************************************************************/
 
 double RHomogeneousTreeLikelihood::getD2LikelihoodForASiteForARateClass(
-  unsigned int site,
-  unsigned int rateClass) const
+  size_t site,
+  size_t rateClass) const
 {
   double d2l = 0;
   Vdouble* d2la = &likelihoodData_->getD2LikelihoodArray(tree_->getRootNode()->getId())[likelihoodData_->getRootArrayPosition(site)][rateClass];
-  for (unsigned int i = 0; i < nbStates_; i++)
+  for (size_t i = 0; i < nbStates_; i++)
   {
     d2l += (*d2la)[i] * rootFreqs_[i];
   }
@@ -563,11 +564,11 @@ double RHomogeneousTreeLikelihood::getD2LikelihoodForASiteForARateClass(
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getD2LikelihoodForASite(unsigned int site) const
+double RHomogeneousTreeLikelihood::getD2LikelihoodForASite(size_t site) const
 {
   // Derivative of the sum is the sum of derivatives:
   double d2l = 0;
-  for (unsigned int i = 0; i < nbClasses_; i++)
+  for (size_t i = 0; i < nbClasses_; i++)
   {
     d2l += getD2LikelihoodForASiteForARateClass(site, i) * rateDistribution_->getProbability(i);
   }
@@ -576,7 +577,7 @@ double RHomogeneousTreeLikelihood::getD2LikelihoodForASite(unsigned int site) co
 
 /******************************************************************************/
 
-double RHomogeneousTreeLikelihood::getD2LogLikelihoodForASite(unsigned int site) const
+double RHomogeneousTreeLikelihood::getD2LogLikelihoodForASite(size_t site) const
 {
   return getD2LikelihoodForASite(site) / getLikelihoodForASite(site)
          - pow( getDLikelihoodForASite(site) / getLikelihoodForASite(site), 2);
@@ -588,7 +589,7 @@ double RHomogeneousTreeLikelihood::getD2LogLikelihood() const
 {
   // Derivative of the sum is the sum of derivatives:
   double dl = 0;
-  for (unsigned int i = 0; i < nbSites_; i++)
+  for (size_t i = 0; i < nbSites_; i++)
   {
     dl += getD2LogLikelihoodForASite(i);
   }
@@ -620,52 +621,52 @@ throw (Exception)
 void RHomogeneousTreeLikelihood::computeTreeD2Likelihood(const string& variable)
 {
   // Get the node with the branch whose length must be derivated:
-  unsigned int brI = TextTools::to<unsigned int>(variable.substr(5));
+  size_t brI = TextTools::to<size_t>(variable.substr(5));
   const Node* branch = nodes_[brI];
   const Node* father = branch->getFather();
 
   // Compute dLikelihoods array for the father node.
   // Fist initialize to 1:
   VVVdouble* _d2Likelihoods_father = &likelihoodData_->getD2LikelihoodArray(father->getId());
-  unsigned int nbSites  = _d2Likelihoods_father->size();
-  for (unsigned int i = 0; i < nbSites; i++)
+  size_t nbSites  = _d2Likelihoods_father->size();
+  for (size_t i = 0; i < nbSites; i++)
   {
     VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-    for (unsigned int c = 0; c < nbClasses_; c++)
+    for (size_t c = 0; c < nbClasses_; c++)
     {
       Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
-      for (unsigned int s = 0; s < nbStates_; s++)
+      for (size_t s = 0; s < nbStates_; s++)
       {
         (*_d2Likelihoods_father_i_c)[s] = 1.;
       }
     }
   }
 
-  unsigned int nbNodes = father->getNumberOfSons();
-  for (unsigned int l = 0; l < nbNodes; l++)
+  size_t nbNodes = father->getNumberOfSons();
+  for (size_t l = 0; l < nbNodes; l++)
   {
     const Node* son = father->getSon(l);
 
-    vector<unsigned int> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
+    vector<size_t> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
     VVVdouble* _likelihoods_son = &likelihoodData_->getLikelihoodArray(son->getId());
 
     if (son == branch)
     {
       VVVdouble* d2pxy__son = &d2pxy_[son->getId()];
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _likelihoods_son_i = &(*_likelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _likelihoods_son_i_c = &(*_likelihoods_son_i)[c];
           Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
           VVdouble* d2pxy__son_c = &(*d2pxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double d2l = 0;
             Vdouble* d2pxy__son_c_x = &(*d2pxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               d2l += (*d2pxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
             }
@@ -677,20 +678,20 @@ void RHomogeneousTreeLikelihood::computeTreeD2Likelihood(const string& variable)
     else
     {
       VVVdouble* pxy__son = &pxy_[son->getId()];
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _likelihoods_son_i = &(*_likelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _likelihoods_son_i_c = &(*_likelihoods_son_i)[c];
           Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
           VVdouble* pxy__son_c = &(*pxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double d2l = 0;
             Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               d2l += (*pxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
             }
@@ -717,45 +718,45 @@ void RHomogeneousTreeLikelihood::computeDownSubtreeD2Likelihood(const Node* node
   // Compute dLikelihoods array for the father node.
   // Fist initialize to 1:
   VVVdouble* _d2Likelihoods_father = &likelihoodData_->getD2LikelihoodArray(father->getId());
-  unsigned int nbSites  = _d2Likelihoods_father->size();
-  for (unsigned int i = 0; i < nbSites; i++)
+  size_t nbSites  = _d2Likelihoods_father->size();
+  for (size_t i = 0; i < nbSites; i++)
   {
     VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-    for (unsigned int c = 0; c < nbClasses_; c++)
+    for (size_t c = 0; c < nbClasses_; c++)
     {
       Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
-      for (unsigned int s = 0; s < nbStates_; s++)
+      for (size_t s = 0; s < nbStates_; s++)
       {
         (*_d2Likelihoods_father_i_c)[s] = 1.;
       }
     }
   }
 
-  unsigned int nbNodes = father->getNumberOfSons();
-  for (unsigned int l = 0; l < nbNodes; l++)
+  size_t nbNodes = father->getNumberOfSons();
+  for (size_t l = 0; l < nbNodes; l++)
   {
     const Node* son = father->getSon(l);
 
     VVVdouble* pxy__son = &pxy_[son->getId()];
-    vector<unsigned int> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
+    vector<size_t> * _patternLinks_father_son = &likelihoodData_->getArrayPositions(father->getId(), son->getId());
 
     if (son == node)
     {
       VVVdouble* _d2Likelihoods_son = &likelihoodData_->getD2LikelihoodArray(son->getId());
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _d2Likelihoods_son_i = &(*_d2Likelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _d2Likelihoods_son_i_c = &(*_d2Likelihoods_son_i)[c];
           Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
           VVdouble* pxy__son_c = &(*pxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double d2l = 0;
             Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               d2l += (*pxy__son_c_x)[y] * (*_d2Likelihoods_son_i_c)[y];
             }
@@ -767,20 +768,20 @@ void RHomogeneousTreeLikelihood::computeDownSubtreeD2Likelihood(const Node* node
     else
     {
       VVVdouble* _likelihoods_son = &likelihoodData_->getLikelihoodArray(son->getId());
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         VVdouble* _likelihoods_son_i = &(*_likelihoods_son)[(*_patternLinks_father_son)[i]];
         VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           Vdouble* _likelihoods_son_i_c = &(*_likelihoods_son_i)[c];
           Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
           VVdouble* pxy__son_c = &(*pxy__son)[c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             double dl = 0;
             Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
-            for (unsigned int y = 0; y < nbStates_; y++)
+            for (size_t y = 0; y < nbStates_; y++)
             {
               dl += (*pxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
             }
@@ -808,20 +809,20 @@ void RHomogeneousTreeLikelihood::computeSubtreeLikelihood(const Node* node)
 {
   if (node->isLeaf()) return;
 
-  unsigned int nbSites = likelihoodData_->getLikelihoodArray(node->getId()).size();
-  unsigned int nbNodes = node->getNumberOfSons();
+  size_t nbSites = likelihoodData_->getLikelihoodArray(node->getId()).size();
+  size_t nbNodes = node->getNumberOfSons();
 
   // Must reset the likelihood array first (i.e. set all of them to 1):
   VVVdouble* _likelihoods_node = &likelihoodData_->getLikelihoodArray(node->getId());
-  for (unsigned int i = 0; i < nbSites; i++)
+  for (size_t i = 0; i < nbSites; i++)
   {
     //For each site in the sequence,
     VVdouble* _likelihoods_node_i = &(*_likelihoods_node)[i];
-    for (unsigned int c = 0; c < nbClasses_; c++)
+    for (size_t c = 0; c < nbClasses_; c++)
     {
       //For each rate classe,
       Vdouble* _likelihoods_node_i_c = &(*_likelihoods_node_i)[c];
-      for (unsigned int x = 0; x < nbStates_; x++)
+      for (size_t x = 0; x < nbStates_; x++)
       {
         //For each initial state,
         (*_likelihoods_node_i_c)[x] = 1.;
@@ -829,7 +830,7 @@ void RHomogeneousTreeLikelihood::computeSubtreeLikelihood(const Node* node)
     }
   }
 
-  for (unsigned int l = 0; l < nbNodes; l++)
+  for (size_t l = 0; l < nbNodes; l++)
   {
     //For each son node,
 
@@ -838,26 +839,26 @@ void RHomogeneousTreeLikelihood::computeSubtreeLikelihood(const Node* node)
     computeSubtreeLikelihood(son); //Recursive method:
 
     VVVdouble* pxy__son = &pxy_[son->getId()];
-    vector<unsigned int> * _patternLinks_node_son = &likelihoodData_->getArrayPositions(node->getId(), son->getId());
+    vector<size_t> * _patternLinks_node_son = &likelihoodData_->getArrayPositions(node->getId(), son->getId());
     VVVdouble* _likelihoods_son = &likelihoodData_->getLikelihoodArray(son->getId());
 
-    for (unsigned int i = 0; i < nbSites; i++)
+    for (size_t i = 0; i < nbSites; i++)
     {
       //For each site in the sequence,
       VVdouble* _likelihoods_son_i = &(*_likelihoods_son)[(*_patternLinks_node_son)[i]];
       VVdouble* _likelihoods_node_i = &(*_likelihoods_node)[i];
-      for (unsigned int c = 0; c < nbClasses_; c++)
+      for (size_t c = 0; c < nbClasses_; c++)
       {
         //For each rate classe,
         Vdouble* _likelihoods_son_i_c = &(*_likelihoods_son_i)[c];
         Vdouble* _likelihoods_node_i_c = &(*_likelihoods_node_i)[c];
         VVdouble* pxy__son_c = &(*pxy__son)[c];
-        for (unsigned int x = 0; x < nbStates_; x++)
+        for (size_t x = 0; x < nbStates_; x++)
         {
           //For each initial state,
           Vdouble* pxy__son_c_x = &(*pxy__son_c)[x];
           double likelihood = 0;
-          for (unsigned int y = 0; y < nbStates_; y++)
+          for (size_t y = 0; y < nbStates_; y++)
           {
             likelihood += (*pxy__son_c_x)[y] * (*_likelihoods_son_i_c)[y];
           }
