@@ -39,7 +39,7 @@
 
 #include "RNonHomogeneousMixedTreeLikelihood.h"
 #include "../PatternTools.h"
-#include "../Model.all"
+#include "../Model/MixedSubstitutionModel.h"
 #include "../TreeTools.h"
 
 #include <Bpp/Numeric/NumConstants.h>
@@ -70,8 +70,8 @@ throw (Exception) :
   if (!modelSet->isFullySetUpFor(tree))
     throw Exception("RNonHomogeneousMixedTreeLikelihood(constructor). Model set is not fully specified.");
 
-  for (unsigned int i=0;i<modelSet->getNumberOfHyperNodes();i++){
-    mvTreeLikelihoods_[tree.getRootId()].push_back(new RNonHomogeneousMixedTreeLikelihood(tree, modelSet, modelSet->getHyperNode(i), upperNode_, rDist, verbose, usePatterns));
+  for (size_t i=0;i<modelSet->getNumberOfHyperNodes();i++){
+    mvTreeLikelihoods_[tree.getRootId()].push_back(new RNonHomogeneousMixedTreeLikelihood(tree, modelSet, modelSet->getHyperNode(i), upperNode_, rDist, false, usePatterns));
   }
 
 }
@@ -94,8 +94,8 @@ throw (Exception) :
   if (!modelSet->isFullySetUpFor(tree))
     throw Exception("RNonHomogeneousMixedTreeLikelihood(constructor). Model set is not fully specified.");
 
-  for (unsigned int i=0;i<modelSet->getNumberOfHyperNodes();i++)
-    mvTreeLikelihoods_[tree.getRootId()].push_back(new RNonHomogeneousMixedTreeLikelihood(tree, data, modelSet, modelSet->getHyperNode(i), upperNode_, rDist, verbose, usePatterns));
+  for (size_t i=0;i<modelSet->getNumberOfHyperNodes();i++)
+    mvTreeLikelihoods_[tree.getRootId()].push_back(new RNonHomogeneousMixedTreeLikelihood(tree, data, modelSet, modelSet->getHyperNode(i), upperNode_, rDist, false, usePatterns));
 }
 
 /******************************************************************************/
@@ -148,11 +148,11 @@ void RNonHomogeneousMixedTreeLikelihood::init(bool usePatterns)
   std::vector<int> vDesc; // vector of the explorated descendents
   int desc;
   vector<int> vn;
-  unsigned int nbmodels = modelSet_->getNumberOfModels();
+  size_t nbmodels = modelSet_->getNumberOfModels();
 
   const SiteContainer* pdata=getData();
   
-  const Tree& tree=getTree();
+  const Tree& tree = getTree();
   
   vDesc.push_back(upperNode_); // start of the exploration
 
@@ -165,14 +165,14 @@ void RNonHomogeneousMixedTreeLikelihood::init(bool usePatterns)
     vector<int> vson = tree.getSonsId(desc);
     std::map<int, vector<int> > mdesc; // map of the subtree nodes for
                                        // each son of desc
-    for (unsigned int i = 0; i < vson.size(); i++)
+    for (size_t i = 0; i < vson.size(); i++)
     {
       std::vector<int> vi;
       TreeTools::getNodesId(tree, vson[i], vi);
       mdesc[vson[i]] = vi;
     }
 
-    for (unsigned int i = 0; i < nbmodels; i++)
+    for (size_t i = 0; i < nbmodels; i++)
     {
       const MixedSubstitutionModelSet::HyperNode::Node& node = hyperNode_.getNode(i);
       
@@ -181,11 +181,11 @@ void RNonHomogeneousMixedTreeLikelihood::init(bool usePatterns)
         vn = modelSet_->getNodesWithModel(i); // tree nodes associated to model
 
         /* Check if the vn members are in the same subtree */
-        unsigned int flag = 0; // count of the subtrees that have vn members
+        size_t flag = 0; // count of the subtrees that have vn members
         std::map<int, vector<int> >::iterator it;
         for (it = mdesc.begin(); it != mdesc.end(); it++)
         {
-          for (unsigned int j = 0; j < it->second.size(); j++)
+          for (size_t j = 0; j < it->second.size(); j++)
             {
             if (it->second[j] != it->first)
             {
@@ -203,37 +203,37 @@ void RNonHomogeneousMixedTreeLikelihood::init(bool usePatterns)
             break;
         }
         if (flag >= 2)
-          vExpMod.push_back(i);  // mixed model that must be expanded
+          vExpMod.push_back(static_cast<int>(i));  // mixed model that must be expanded
       }
     }
 
     if (vExpMod.size() != 0)
     {
       std::map<int, int> mapmodels;
-      unsigned int ttmodels = 1;
+      size_t ttmodels = 1;
       for (vector<int>::iterator it = vExpMod.begin(); it != vExpMod.end(); it++)
       {
-        mapmodels[*it] = hyperNode_.getNode(*it).size();
+        mapmodels[*it] = static_cast<int>(hyperNode_.getNode(*it).size());
         ttmodels *= mapmodels[*it];
       }
 
-      for (unsigned int i = 0; i < ttmodels; i++)
+      for (size_t i = 0; i < ttmodels; i++)
       {
-        unsigned int s = i;
+        int s = static_cast<int>(i);
         MixedSubstitutionModelSet::HyperNode hn(hyperNode_);
         
-        for (unsigned int j = 0; j < nbmodels; j++)
+        for (size_t j = 0; j < nbmodels; j++)
         {
-          if ((hyperNode_.getNode(j).size()>=1) && find(vExpMod.begin(), vExpMod.end(), static_cast<int>(j)) != vExpMod.end())
+          if ((hyperNode_.getNode(j).size() >= 1) && find(vExpMod.begin(), vExpMod.end(), static_cast<int>(j)) != vExpMod.end())
           {
-            hn.setModel(j,Vint(1,hyperNode_.getNode(j)[s % mapmodels[j]]));
-            s /= mapmodels[j];
+            hn.setModel(j, Vint(1, hyperNode_.getNode(j)[s % mapmodels[static_cast<int>(j)]]));
+            s /= mapmodels[static_cast<int>(j)];
           }
         }
         hn.setProbability((dynamic_cast<MixedSubstitutionModelSet*>(modelSet_))->getHyperNodeProbability(hn));
         RNonHomogeneousMixedTreeLikelihood* pr;
 
-        if (pdata != NULL)
+        if (pdata)
           pr = new RNonHomogeneousMixedTreeLikelihood(tree, *pdata, dynamic_cast<MixedSubstitutionModelSet*>(modelSet_), hn, desc, rateDistribution_, false, usePatterns);
         else
           pr = new RNonHomogeneousMixedTreeLikelihood(tree, dynamic_cast<MixedSubstitutionModelSet*>(modelSet_), hn, desc, rateDistribution_, false, usePatterns);
@@ -242,7 +242,7 @@ void RNonHomogeneousMixedTreeLikelihood::init(bool usePatterns)
       }
     }
     else
-      for (unsigned int i = 0; i < vson.size(); i++)
+      for (size_t i = 0; i < vson.size(); i++)
       {
         vDesc.push_back(vson[i]);
       }
@@ -263,7 +263,7 @@ RNonHomogeneousMixedTreeLikelihood::RNonHomogeneousMixedTreeLikelihood(
   map<int, vector<RNonHomogeneousMixedTreeLikelihood*> >::const_iterator it;
   for (it = lik.mvTreeLikelihoods_.begin(); it != lik.mvTreeLikelihoods_.end(); it++)
   {
-    for (unsigned int i = 0; i < it->second.size(); i++)
+    for (size_t i = 0; i < it->second.size(); i++)
     {
       mvTreeLikelihoods_[it->first].push_back(new RNonHomogeneousMixedTreeLikelihood(*it->second[i]));
     }
@@ -285,7 +285,7 @@ RNonHomogeneousMixedTreeLikelihood& RNonHomogeneousMixedTreeLikelihood::operator
   map<int, vector<RNonHomogeneousMixedTreeLikelihood*> >::const_iterator it;
   for (it = lik.mvTreeLikelihoods_.begin(); it != lik.mvTreeLikelihoods_.end(); it++)
   {
-    for (unsigned int i = 0; i < it->second.size(); i++)
+    for (size_t i = 0; i < it->second.size(); i++)
     {
       mvTreeLikelihoods_[it->first].push_back(new RNonHomogeneousMixedTreeLikelihood(*it->second[i]));
     }
@@ -303,7 +303,7 @@ RNonHomogeneousMixedTreeLikelihood::~RNonHomogeneousMixedTreeLikelihood()
   map<int, vector<RNonHomogeneousMixedTreeLikelihood*> >::iterator it;
   for (it = mvTreeLikelihoods_.begin(); it != mvTreeLikelihoods_.end(); it++)
   {
-    for (unsigned int i = 0; i < it->second.size(); i++)
+    for (size_t i = 0; i < it->second.size(); i++)
     {
       delete it->second[i];
     }
@@ -323,7 +323,7 @@ RNonHomogeneousMixedTreeLikelihood::~RNonHomogeneousMixedTreeLikelihood()
   map<int, vector<RNonHomogeneousMixedTreeLikelihood*> >::iterator it;
   for (it = mvTreeLikelihoods_.begin(); it != mvTreeLikelihoods_.end(); it++)
   {
-    for (unsigned int i = 0; i < it->second.size(); i++)
+    for (size_t i = 0; i < it->second.size(); i++)
     {
       it->second[i]->initialize();
     }
@@ -339,7 +339,7 @@ RNonHomogeneousMixedTreeLikelihood::~RNonHomogeneousMixedTreeLikelihood()
   if (main_)
     applyParameters();
   else {
-    for (unsigned int i = 0; i < nbNodes_; i++)
+    for (size_t i = 0; i < nbNodes_; i++)
       {
         int id = nodes_[i]->getId();
         if (reparametrizeRoot_ && id == root1_)
@@ -364,12 +364,12 @@ RNonHomogeneousMixedTreeLikelihood::~RNonHomogeneousMixedTreeLikelihood()
 
   map<int, vector<RNonHomogeneousMixedTreeLikelihood*> >::const_iterator it2;
   for (it2 = mvTreeLikelihoods_.begin(); it2 != mvTreeLikelihoods_.end(); it2++)
-    for (unsigned int i = 0; i < it2->second.size(); i++){
+    for (size_t i = 0; i < it2->second.size(); i++){
       (it2->second)[i]->setProbability((dynamic_cast<MixedSubstitutionModelSet*>(modelSet_))->getHyperNodeProbability((it2->second)[i]->getHyperNode()));
     }
 
   if (main_){
-    for (unsigned int i=0;i< mvTreeLikelihoods_[upperNode_].size(); i++)
+    for (size_t i=0;i< mvTreeLikelihoods_[upperNode_].size(); i++)
       mvTreeLikelihoods_[upperNode_][i]->matchParametersValues(params);
     rootFreqs_ = modelSet_->getRootFrequencies();
   }
@@ -382,20 +382,20 @@ RNonHomogeneousMixedTreeLikelihood::~RNonHomogeneousMixedTreeLikelihood()
       {
         vector<int> ids;
         vector<string> tmp = params.getCommonParametersWith(modelSet_->getNodeParameters()).getParameterNames();
-        for (unsigned int i = 0; i < tmp.size(); i++)
+        for (size_t i = 0; i < tmp.size(); i++)
           {
             vector<int> tmpv = modelSet_->getNodesWithParameter(tmp[i]);
             ids = VectorTools::vectorUnion(ids, tmpv);
           }
         tmp = params.getCommonParametersWith(brLenParameters_).getParameterNames();
         vector<const Node*> nodes;
-        for (unsigned int i = 0; i < ids.size(); i++)
+        for (size_t i = 0; i < ids.size(); i++)
           {
             nodes.push_back(idToNode_[ids[i]]);
           }
         vector<const Node*> tmpv;
         bool test = false;
-        for (unsigned int i = 0; i < tmp.size(); i++)
+        for (size_t i = 0; i < tmp.size(); i++)
           {
             if (tmp[i] == "BrLenRoot" || tmp[i] == "RootPosition")
               {
@@ -407,11 +407,11 @@ RNonHomogeneousMixedTreeLikelihood::~RNonHomogeneousMixedTreeLikelihood()
                   }
               }
             else
-              tmpv.push_back(nodes_[TextTools::to < unsigned int > (tmp[i].substr(5))]);
+              tmpv.push_back(nodes_[TextTools::to < size_t > (tmp[i].substr(5))]);
           }
         nodes = VectorTools::vectorUnion(nodes, tmpv);
         
-        for (unsigned int i = 0; i < nodes.size(); i++){
+        for (size_t i = 0; i < nodes.size(); i++){
           computeTransitionProbabilitiesForNode(nodes[i]);
         }
       }
@@ -419,7 +419,7 @@ RNonHomogeneousMixedTreeLikelihood::~RNonHomogeneousMixedTreeLikelihood()
     map<int, vector<RNonHomogeneousMixedTreeLikelihood*> >::iterator it;
     for (it = mvTreeLikelihoods_.begin(); it != mvTreeLikelihoods_.end(); it++)
       {
-        for (unsigned int i = 0; i < it->second.size(); i++)
+        for (size_t i = 0; i < it->second.size(); i++)
           {
             it->second[i]->matchParametersValues(params);
           }
@@ -440,7 +440,7 @@ void RNonHomogeneousMixedTreeLikelihood::setData(const SiteContainer& sites) thr
   map<int, vector<RNonHomogeneousMixedTreeLikelihood*> >::iterator it;
   for (it = mvTreeLikelihoods_.begin(); it != mvTreeLikelihoods_.end(); it++)
   {
-    for (unsigned int i = 0; i < it->second.size(); i++)
+    for (size_t i = 0; i < it->second.size(); i++)
     {
       it->second[i]->setData(sites);
     }
@@ -471,19 +471,19 @@ void RNonHomogeneousMixedTreeLikelihood::computeSubtreeLikelihood(const Node* no
   int nodeId=main_?upperNode_:node->getId();
   if (mvTreeLikelihoods_.find(nodeId) != mvTreeLikelihoods_.end()) {
 
-    unsigned int nbSites  = likelihoodData_->getLikelihoodArray(nodeId).size();
+    size_t nbSites  = likelihoodData_->getLikelihoodArray(nodeId).size();
     
     // Must reset the likelihood array first (i.e. set all of them to 0):
     VVVdouble* _likelihoods_node = &likelihoodData_->getLikelihoodArray(nodeId);
-    for (unsigned int i = 0; i < nbSites; i++)
+    for (size_t i = 0; i < nbSites; i++)
       {
         // For each site in the sequence,
         VVdouble* _likelihoods_node_i = &(*_likelihoods_node)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
           {
-            // For each rate classe,
+              // For each rate classe,
             Vdouble* _likelihoods_node_i_c = &(*_likelihoods_node_i)[c];
-            for (unsigned int x = 0; x < nbStates_; x++)
+            for (size_t x = 0; x < nbStates_; x++)
               {
                 // For each initial state,
                 (*_likelihoods_node_i_c)[x] = 0.;
@@ -491,24 +491,27 @@ void RNonHomogeneousMixedTreeLikelihood::computeSubtreeLikelihood(const Node* no
           }
       }
 
+    if (getProbability()==0)
+      return;
+  
     vector<RNonHomogeneousMixedTreeLikelihood* > vr = mvTreeLikelihoods_[nodeId];
-    for (unsigned int t = 0; t < vr.size(); t++)
+    for (size_t t = 0; t < vr.size(); t++)
       vr[t]->computeSubtreeLikelihood(node);
 
     // for each specific subtree
-    for (unsigned int t = 0; t < vr.size(); t++)
+    for (size_t t = 0; t < vr.size(); t++)
     {
       VVVdouble* _vt_likelihoods_node = &vr[t]->likelihoodData_->getLikelihoodArray(nodeId);
-      for (unsigned int i = 0; i < nbSites; i++)
+      for (size_t i = 0; i < nbSites; i++)
       {
         // For each site in the sequence,
         VVdouble* _likelihoods_node_i = &(*_likelihoods_node)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++)
+        for (size_t c = 0; c < nbClasses_; c++)
         {
           // For each rate classe,
           Vdouble* _likelihoods_node_i_c = &(*_likelihoods_node_i)[c];
           Vdouble* _vt_likelihoods_node_i_c = &(*_vt_likelihoods_node)[i][c];
-          for (unsigned int x = 0; x < nbStates_; x++)
+          for (size_t x = 0; x < nbStates_; x++)
           {
             (*_likelihoods_node_i_c)[x] +=  (*_vt_likelihoods_node_i_c)[x] * vr[t]->getProbability()/getProbability();
           }
@@ -543,7 +546,7 @@ void RNonHomogeneousMixedTreeLikelihood::computeTreeDLikelihood(const string& va
       father = tree_->getRootNode();
     else
       {
-        unsigned int brI = TextTools::to<unsigned int>(variable.substr(5));
+        size_t brI = TextTools::to<size_t>(variable.substr(5));
         const Node* branch = nodes_[brI];
         father = branch->getFather();
       }
@@ -565,34 +568,36 @@ void RNonHomogeneousMixedTreeLikelihood::computeTreeDLikelihood(const string& va
     // Compute dLikelihoods array for the father node.
     // Fist initialize to 0:
     VVVdouble* _dLikelihoods_father = &likelihoodData_->getDLikelihoodArray(fatherId);
-    unsigned int nbSites  = _dLikelihoods_father->size();
-    for (unsigned int i = 0; i < nbSites; i++) {
+    size_t nbSites  = _dLikelihoods_father->size();
+    for (size_t i = 0; i < nbSites; i++) {
       VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-      for (unsigned int c = 0; c < nbClasses_; c++) {
+      for (size_t c = 0; c < nbClasses_; c++) {
         Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
-        for (unsigned int s = 0; s < nbStates_; s++){
+        for (size_t s = 0; s < nbStates_; s++){
           (*_dLikelihoods_father_i_c)[s] = 0.;
         }
       }
     }
-        
-    vector<RNonHomogeneousMixedTreeLikelihood* > vr = mvTreeLikelihoods_[fatherId];
-    for (unsigned int t = 0; t < vr.size(); t++)
-      vr[t]->computeTreeDLikelihood(variable);
-   
+
+    if (getProbability()!=0){
+      vector<RNonHomogeneousMixedTreeLikelihood* > vr = mvTreeLikelihoods_[fatherId];
+      for (size_t t = 0; t < vr.size(); t++)
+        vr[t]->computeTreeDLikelihood(variable);
+      
     
-    // for each specific subtree
-    for (unsigned int t = 0; t < vr.size(); t++) {
-      VVVdouble* _vt_dLikelihoods_father = &vr[t]->likelihoodData_->getDLikelihoodArray(fatherId);
-      for (unsigned int i = 0; i < nbSites; i++){
-        // For each site in the sequence,
-        VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++){
-          // For each rate classe,
-          Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
-          Vdouble* _vt_dLikelihoods_father_i_c = &(*_vt_dLikelihoods_father)[i][c];
-          for (unsigned int x = 0; x < nbStates_; x++) {
-            (*_dLikelihoods_father_i_c)[x] +=  (*_vt_dLikelihoods_father_i_c)[x] * vr[t]->getProbability()/getProbability();
+      // for each specific subtree
+      for (size_t t = 0; t < vr.size(); t++) {
+        VVVdouble* _vt_dLikelihoods_father = &vr[t]->likelihoodData_->getDLikelihoodArray(fatherId);
+        for (size_t i = 0; i < nbSites; i++){
+          // For each site in the sequence,
+          VVdouble* _dLikelihoods_father_i = &(*_dLikelihoods_father)[i];
+          for (size_t c = 0; c < nbClasses_; c++){
+            // For each rate classe,
+            Vdouble* _dLikelihoods_father_i_c = &(*_dLikelihoods_father_i)[c];
+            Vdouble* _vt_dLikelihoods_father_i_c = &(*_vt_dLikelihoods_father)[i][c];
+            for (size_t x = 0; x < nbStates_; x++) {
+              (*_dLikelihoods_father_i_c)[x] +=  (*_vt_dLikelihoods_father_i_c)[x] * vr[t]->getProbability()/getProbability();
+            }
           }
         }
       }
@@ -631,7 +636,7 @@ void RNonHomogeneousMixedTreeLikelihood::computeTreeD2Likelihood(const string& v
       father = tree_->getRootNode();
     else
       {
-        unsigned int brI = TextTools::to<unsigned int>(variable.substr(5));
+        size_t brI = TextTools::to<size_t>(variable.substr(5));
         const Node* branch = nodes_[brI];
         father = branch->getFather();
       }
@@ -655,33 +660,36 @@ void RNonHomogeneousMixedTreeLikelihood::computeTreeD2Likelihood(const string& v
       // Compute d2Likelihoods array for the father node.
       // Fist initialize to 0:
       VVVdouble* _d2Likelihoods_father = &likelihoodData_->getD2LikelihoodArray(fatherId);
-      unsigned int nbSites  = _d2Likelihoods_father->size();
-      for (unsigned int i = 0; i < nbSites; i++) {
+      size_t nbSites  = _d2Likelihoods_father->size();
+      for (size_t i = 0; i < nbSites; i++) {
         VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-        for (unsigned int c = 0; c < nbClasses_; c++) {
+        for (size_t c = 0; c < nbClasses_; c++) {
           Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
-          for (unsigned int s = 0; s < nbStates_; s++) {
+          for (size_t s = 0; s < nbStates_; s++) {
             (*_d2Likelihoods_father_i_c)[s] = 0.;
           }
         }
       }
 
-      vector<RNonHomogeneousMixedTreeLikelihood* > vr = mvTreeLikelihoods_[fatherId];
-      for (unsigned int t = 0; t < vr.size(); t++)
-        vr[t]->computeTreeD2Likelihood(variable);
+      if (getProbability()!=0){
+        
+        vector<RNonHomogeneousMixedTreeLikelihood* > vr = mvTreeLikelihoods_[fatherId];
+        for (size_t t = 0; t < vr.size(); t++)
+          vr[t]->computeTreeD2Likelihood(variable);
       
-      // for each specific subtree
-      for (unsigned int t = 0; t < vr.size(); t++) {
-        VVVdouble* _vt_d2Likelihoods_father = &vr[t]->likelihoodData_->getD2LikelihoodArray(fatherId);
-        for (unsigned int i = 0; i < nbSites; i++) {
-          // For each site in the sequence,
-          VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
-          for (unsigned int c = 0; c < nbClasses_; c++){
-            // For each rate classe,
-            Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
-            Vdouble* _vt_d2Likelihoods_father_i_c = &(*_vt_d2Likelihoods_father)[i][c];
-            for (unsigned int x = 0; x < nbStates_; x++) {
-              (*_d2Likelihoods_father_i_c)[x] +=  (*_vt_d2Likelihoods_father_i_c)[x] * vr[t]->getProbability() / getProbability();
+        // for each specific subtree
+        for (size_t t = 0; t < vr.size(); t++) {
+          VVVdouble* _vt_d2Likelihoods_father = &vr[t]->likelihoodData_->getD2LikelihoodArray(fatherId);
+          for (size_t i = 0; i < nbSites; i++) {
+            // For each site in the sequence,
+            VVdouble* _d2Likelihoods_father_i = &(*_d2Likelihoods_father)[i];
+            for (size_t c = 0; c < nbClasses_; c++){
+              // For each rate classe,
+              Vdouble* _d2Likelihoods_father_i_c = &(*_d2Likelihoods_father_i)[c];
+              Vdouble* _vt_d2Likelihoods_father_i_c = &(*_vt_d2Likelihoods_father)[i][c];
+              for (size_t x = 0; x < nbStates_; x++) {
+                (*_d2Likelihoods_father_i_c)[x] +=  (*_vt_d2Likelihoods_father_i_c)[x] * vr[t]->getProbability() / getProbability();
+              }
             }
           }
         }
@@ -713,72 +721,72 @@ void RNonHomogeneousMixedTreeLikelihood::computeDownSubtreeD2Likelihood(const No
 void RNonHomogeneousMixedTreeLikelihood::computeTransitionProbabilitiesForNode(const Node* node)
 {
   const SubstitutionModel* model = modelSet_->getModelForNode(node->getId());
-  int modelnum = modelSet_->getModelIndexForNode(node->getId());
+  size_t modelnum = modelSet_->getModelIndexForNode(node->getId());
 
   vector<const SubstitutionModel*> vModel;
   vector<double> vProba;
   
   const MixedSubstitutionModelSet::HyperNode::Node& nd=hyperNode_.getNode(modelnum);
-  if (nd.size()==0){
+  if (nd.size() == 0) {
     vModel.push_back(model);
     vProba.push_back(1);
   }
-  else{
+  else {
     const MixedSubstitutionModel* mmodel = dynamic_cast<const MixedSubstitutionModel*>(model);
     double x=0;
-    for (unsigned int i=0;i<nd.size();i++){
+    for (size_t i=0;i<nd.size();i++){
       vModel.push_back(mmodel->getNModel(nd[i]));
       vProba.push_back(mmodel->getNProbability(nd[i]));
       x+=vProba[i];
     }
-    for (unsigned int i=0;i<nd.size();i++)
-      vProba[i]/=x;
+    if (x!=0)
+      for (size_t i=0;i<nd.size();i++)
+        vProba[i]/=x;
   }
 
   double l = node->getDistanceToFather();
   // Computes all pxy and pyx once for all:
   VVVdouble* pxy__node = &pxy_[node->getId()];
-  for (unsigned int c = 0; c < nbClasses_; c++){
-
+  for (size_t c = 0; c < nbClasses_; c++) {
     VVdouble* pxy__node_c = &(*pxy__node)[c];
-    for (unsigned int x = 0; x < nbStates_; x++){
+    for (size_t x = 0; x < nbStates_; x++){
       Vdouble* pxy__node_c_x = &(*pxy__node_c)[x];
-      for (unsigned int y = 0; y < nbStates_; y++){
+      for (size_t y = 0; y < nbStates_; y++){
         (*pxy__node_c_x)[y] = 0;
       }
     }
     
-    for (unsigned int i=0;i<vModel.size();i++){
+    for (size_t i=0;i<vModel.size();i++){
       RowMatrix<double> Q = vModel[i]->getPij_t(l * rateDistribution_->getCategory(c));
-      for (unsigned int x = 0; x < nbStates_; x++){
+      for (size_t x = 0; x < nbStates_; x++){
         Vdouble* pxy__node_c_x = &(*pxy__node_c)[x];
-        for (unsigned int y = 0; y < nbStates_; y++){
+        for (size_t y = 0; y < nbStates_; y++){
           (*pxy__node_c_x)[y] += vProba[i] * Q(x, y);
         }
       }
     }
   }
   
-  if (computeFirstOrderDerivatives_){
+  if (computeFirstOrderDerivatives_) {
     // Computes all dpxy/dt once for all:
     VVVdouble* dpxy__node = &dpxy_[node->getId()];
 
-    for (unsigned int c = 0; c < nbClasses_; c++){
+    for (size_t c = 0; c < nbClasses_; c++){
       VVdouble* dpxy__node_c = &(*dpxy__node)[c];
       double rc = rateDistribution_->getCategory(c);
-      for (unsigned int x = 0; x < nbStates_; x++){
+      for (size_t x = 0; x < nbStates_; x++){
         Vdouble* dpxy__node_c_x = &(*dpxy__node_c)[x];
-        for (unsigned int y = 0; y < nbStates_; y++){
+        for (size_t y = 0; y < nbStates_; y++){
           (*dpxy__node_c_x)[y] = 0;
         }
       }
 
-      for (unsigned int i=0;i<vModel.size();i++){
+      for (size_t i=0;i<vModel.size();i++){
         RowMatrix<double> dQ = vModel[i]->getdPij_dt(l * rc);
 
-        for (unsigned int x = 0; x < nbStates_; x++){
+        for (size_t x = 0; x < nbStates_; x++){
           Vdouble* dpxy__node_c_x = &(*dpxy__node_c)[x];
-          for (unsigned int y = 0; y < nbStates_; y++){
+          for (size_t y = 0; y < nbStates_; y++){
             (*dpxy__node_c_x)[y] +=  vProba[i] * rc * dQ(x, y);
           }
         }
@@ -786,24 +794,24 @@ void RNonHomogeneousMixedTreeLikelihood::computeTransitionProbabilitiesForNode(c
     }
   }
   
-  if (computeSecondOrderDerivatives_){
+  if (computeSecondOrderDerivatives_) {
     // Computes all d2pxy/dt2 once for all:
     VVVdouble* d2pxy__node = &d2pxy_[node->getId()];
-    for (unsigned int c = 0; c < nbClasses_; c++){
+    for (size_t c = 0; c < nbClasses_; c++){
       VVdouble* d2pxy__node_c = &(*d2pxy__node)[c];
-      for (unsigned int x = 0; x < nbStates_; x++){
+      for (size_t x = 0; x < nbStates_; x++){
         Vdouble* d2pxy__node_c_x = &(*d2pxy__node_c)[x];
-        for (unsigned int y = 0; y < nbStates_; y++){
+        for (size_t y = 0; y < nbStates_; y++){
           (*d2pxy__node_c_x)[y] = 0;
         }
       }
       
       double rc =  rateDistribution_->getCategory(c);
-      for (unsigned int i=0;i<vModel.size();i++){
+      for (size_t i=0;i<vModel.size();i++){
         RowMatrix<double> d2Q = vModel[i]->getd2Pij_dt2(l * rc);
-        for (unsigned int x = 0; x < nbStates_; x++){
+        for (size_t x = 0; x < nbStates_; x++){
           Vdouble* d2pxy__node_c_x = &(*d2pxy__node_c)[x];
-          for (unsigned int y = 0; y < nbStates_; y++){
+          for (size_t y = 0; y < nbStates_; y++){
             (*d2pxy__node_c_x)[y] +=  vProba[i] * rc * rc * d2Q(x, y);
           }
         }
