@@ -4,7 +4,7 @@
 //
 
 /*
-   Copyright or © or Copr. CNRS, (November 16, 2004)
+   Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)
 
    This software is a computer program whose purpose is to provide classes
    for phylogenetic data analysis.
@@ -40,7 +40,8 @@
 #define _MIXTUREOFASUBSTITUTIONMODEL_H_
 
 #include "AbstractMixedSubstitutionModel.h"
-#include <Bpp/Numeric/Prob.all>
+
+#include <Bpp/Numeric/Prob/DiscreteDistribution.h>
 #include <Bpp/Numeric/VectorTools.h>
 
 #include <vector>
@@ -121,7 +122,7 @@ public:
   MixtureOfASubstitutionModel* clone() const { return new MixtureOfASubstitutionModel(*this); }
 
 public:
-  std::string getName() const { return "MixtureOfASubstitutionModel"; }
+  std::string getName() const { return "MixedModel"; }
 
   void updateMatrices();
 
@@ -145,7 +146,23 @@ public:
 
   void setFreq(std::map<int,double>&);
 
+  /**
+   * @brief returns the DiscreteDistribution associated with a given
+   * parameter name.
+   * @param parName name of the parameter
+   **/
+
+  const DiscreteDistribution* getDistribution(std::string& parName) const;
+
+  /**
+   *@brief Numbers of the states between which the substitution rates
+   *of all the submodels must be equal. If they are set to -1, this
+   *constraint does not exist among the submodels.
+   *
+   */
   
+  int from() const { return from_;}
+  int to() const { return to_;}
 };
 } // end of namespace bpp.
 
