@@ -40,7 +40,7 @@
 #ifndef _MIXTUREOFSUBSTITUTIONMODELS_H_
 #define _MIXTUREOFSUBSTITUTIONMODELS_H_
 
-#include <Bpp/Numeric/Prob.all>
+// #include <Bpp/Numeric/Prob.all>
 #include <Bpp/Numeric/VectorTools.h>
 #include "AbstractMixedSubstitutionModel.h"
 
@@ -159,7 +159,7 @@ namespace bpp
     MixtureOfSubstitutionModels* clone() const { return new MixtureOfSubstitutionModels(*this); }
 
   public:
-    std::string getName() const { return "MixtureOfSubstitutionModels"; }
+    std::string getName() const { return "Mixture"; }
 
     void updateMatrices();
   
