@@ -47,7 +47,7 @@ using namespace std;
 
 /******************************************************************************/
 
-RE08::RE08(ReversibleSubstitutionModel *simpleModel, double lambda, double mu) :
+RE08::RE08(ReversibleSubstitutionModel* simpleModel, double lambda, double mu) :
   AbstractParameterAliasable("RE08."),
   AbstractSubstitutionModel(simpleModel->getAlphabet(), "RE08."),
   AbstractReversibleSubstitutionModel(simpleModel->getAlphabet(), "RE08."),
@@ -57,10 +57,8 @@ RE08::RE08(ReversibleSubstitutionModel *simpleModel, double lambda, double mu) :
   exp_(), p_(), lambda_(lambda), mu_(mu),
   nestedPrefix_("model_" + simpleModel->getNamespace())
 {
-  Parameter lambdaP("RE08.lambda", lambda, &Parameter::R_PLUS);  
-  addParameter_(lambdaP);  
-  Parameter muP("RE08.mu", mu, &Parameter::R_PLUS);
-  addParameter_(muP);
+  addParameter_(new Parameter("RE08.lambda", lambda, &Parameter::R_PLUS));  
+  addParameter_(new Parameter("RE08.mu", mu, &Parameter::R_PLUS));
   simpleModel_->setNamespace("RE08." + nestedPrefix_);
   addParameters_(simpleModel->getParameters());
   //We need to overrired this from the AbstractSubstitutionModel constructor,
@@ -84,7 +82,7 @@ void RE08::updateMatrices()
   double f = (lambda_ == 0 && mu_ == 0) ? 1 : lambda_ / (lambda_ + mu_);
   
   // Frequencies:
-  for(unsigned int i = 0; i < size_ - 1; i++)
+  for(size_t i = 0; i < size_ - 1; i++)
     freq_[i] = simpleModel_->freq(i) * f;
 
   freq_[size_-1] = (1. - f);
@@ -93,9 +91,9 @@ void RE08::updateMatrices()
   simpleExchangeabilities_ = simpleModel_->getExchangeabilityMatrix();
 
   // Generator and exchangeabilities:
-  for (unsigned int i = 0; i < size_ - 1; i++)
+  for (size_t i = 0; i < size_ - 1; i++)
   {
-    for (unsigned int j = 0; j < size_ - 1; j++)
+    for (size_t j = 0; j < size_ - 1; j++)
     {
       generator_(i, j) = simpleGenerator_(i, j);
       exchangeability_(i, j) = simpleExchangeabilities_(i, j) / f;
@@ -121,7 +119,7 @@ void RE08::updateMatrices()
   
 /******************************************************************************/
 
-double RE08::Pij_t(unsigned int i, unsigned int j, double d) const
+double RE08::Pij_t(size_t i, size_t j, double d) const
 {
   double f = (lambda_ == 0 && mu_ == 0) ? 1. : lambda_ / (lambda_ + mu_);
   if(i < size_ - 1 && j < size_ - 1)
@@ -151,7 +149,7 @@ double RE08::Pij_t(unsigned int i, unsigned int j, double d) const
 
 /******************************************************************************/
 
-double RE08::dPij_dt(unsigned int i, unsigned int j, double d) const
+double RE08::dPij_dt(size_t i, size_t j, double d) const
 {
   double f = (lambda_ == 0 && mu_ == 0) ? 1. : lambda_ / (lambda_ + mu_);
   if(i < size_ - 1 && j < size_ - 1)
@@ -182,7 +180,7 @@ double RE08::dPij_dt(unsigned int i, unsigned int j, double d) const
 
 /******************************************************************************/
 
-double RE08::d2Pij_dt2(unsigned int i, unsigned int j, double d) const
+double RE08::d2Pij_dt2(size_t i, size_t j, double d) const
 {
   double f = (lambda_ == 0 && mu_ == 0) ? 1. : lambda_ / (lambda_ + mu_);
   if(i < size_ - 1 && j < size_ - 1)
@@ -218,20 +216,20 @@ const Matrix<double> & RE08::getPij_t(double d) const
 {
   RowMatrix<double> simpleP = simpleModel_->getPij_t(d);
   double f = (lambda_ == 0 && mu_ == 0) ? 1. : lambda_ / (lambda_ + mu_);
-  for (unsigned int i = 0; i < size_ - 1; i++)
+  for (size_t i = 0; i < size_ - 1; i++)
   {
-    for (unsigned int j = 0; j < size_ - 1; j++)
+    for (size_t j = 0; j < size_ - 1; j++)
     {
       p_(i, j) = (simpleP(i, j) - simpleModel_->freq(j)) * exp(-mu_ * d)
           + freq_[j] + (simpleModel_->freq(j) - freq_[j]) * exp(-(lambda_ + mu_) * d);
     }
   }
-  for(unsigned int j = 0; j < size_ - 1; j++)
+  for(size_t j = 0; j < size_ - 1; j++)
   {
     p_(size_ - 1, j) = freq_[j] * (1. - exp(-(lambda_ + mu_) * d));
   }
   p_(size_ - 1, size_ - 1) = 1. - f * (1. - exp(-(lambda_ + mu_) * d));
-  for(unsigned int i = 0; i < size_ - 1; i++)
+  for(size_t i = 0; i < size_ - 1; i++)
   {  
     p_(i, size_ - 1) = freq_[size_ - 1] * (1. - exp(-(lambda_ + mu_) * d));
   }
@@ -245,21 +243,21 @@ const Matrix<double> & RE08::getdPij_dt(double d) const
   RowMatrix<double> simpleP = simpleModel_->getPij_t(d);
   RowMatrix<double> simpleDP = simpleModel_->getdPij_dt(d);
   double f = (lambda_ == 0 && mu_ == 0) ? 1. : lambda_ / (lambda_ + mu_);
-  for (unsigned int i = 0; i < size_ - 1; i++)
+  for (size_t i = 0; i < size_ - 1; i++)
   {
-    for (unsigned int j = 0; j < size_ - 1; j++)
+    for (size_t j = 0; j < size_ - 1; j++)
     {
       p_(i, j) = simpleDP(i, j) * exp(-mu_ * d)
           - mu_ * (simpleP(i, j) - simpleModel_->freq(j)) * exp(-mu_ * d)
           - (lambda_ + mu_) * (simpleModel_->freq(j) - freq_[j]) * exp(-(lambda_ + mu_) * d);
     }
   }
-  for (unsigned int j = 0; j < size_ - 1; j++)
+  for (size_t j = 0; j < size_ - 1; j++)
   {
     p_(size_ - 1, j) = (lambda_ + mu_) * freq_[j] * exp(-(lambda_ + mu_) * d);
   }
   p_(size_ - 1, size_ - 1) = - f * (lambda_ + mu_) * exp(-(lambda_ + mu_) * d);
-  for (unsigned int i = 0; i < size_ - 1; i++)
+  for (size_t i = 0; i < size_ - 1; i++)
   {  
     p_(i, size_ - 1) = (lambda_ + mu_) * freq_[size_ - 1] * exp(-(lambda_ + mu_) * d);
   }
@@ -274,9 +272,9 @@ const Matrix<double> & RE08::getd2Pij_dt2(double d) const
   RowMatrix<double> simpleDP = simpleModel_->getdPij_dt(d);
   RowMatrix<double> simpleD2P = simpleModel_->getd2Pij_dt2(d);
   double f = (lambda_ == 0 && mu_ == 0) ? 1. : lambda_ / (lambda_ + mu_);
-  for (unsigned int i = 0; i < size_ - 1; i++)
+  for (size_t i = 0; i < size_ - 1; i++)
   {
-    for (unsigned int j = 0; j < size_ - 1; j++)
+    for (size_t j = 0; j < size_ - 1; j++)
     {
       p_(i, j) = simpleD2P(i, j) * exp(-mu_ * d)
           - 2 * mu_ * simpleDP(i, j) * exp(-mu_ * d)
@@ -284,12 +282,12 @@ const Matrix<double> & RE08::getd2Pij_dt2(double d) const
           + (lambda_ + mu_) * (lambda_ + mu_) * (simpleModel_->freq(j) - freq_[j]) * exp(-(lambda_ + mu_) * d);
     }
   }
-  for (unsigned int j = 0; j < size_ - 1; j++)
+  for (size_t j = 0; j < size_ - 1; j++)
   {
     p_(size_ - 1, j) = - (lambda_ + mu_) * (lambda_ + mu_) * freq_[j] * exp(-(lambda_ + mu_) * d);
   }
   p_(size_ - 1, size_ - 1) = f * (lambda_ + mu_) * (lambda_ + mu_) * exp(-(lambda_ + mu_) * d);
-  for(unsigned int i = 0; i < size_ - 1; i++)
+  for(size_t i = 0; i < size_ - 1; i++)
   {  
     p_(i, size_ - 1) = - (lambda_ + mu_) * (lambda_ + mu_) * freq_[size_ - 1] * exp(-(lambda_ + mu_) * d);
   }
@@ -298,14 +296,14 @@ const Matrix<double> & RE08::getd2Pij_dt2(double d) const
 
 /******************************************************************************/
 
-double RE08::getInitValue(unsigned int i, int state) const throw (BadIntException)
+double RE08::getInitValue(size_t i, int state) const throw (IndexOutOfBoundsException, BadIntException)
 {
-  if (i >= size_) throw BadIntException(i, "RE08::getInitValue");
+  if (i >= size_) throw IndexOutOfBoundsException("RE08::getInitValue", i, 0, size_ - 1);
   if (state < -1 || !getAlphabet()->isIntInAlphabet(state))
     throw BadIntException(state, "RE08::getInitValue. Character " + getAlphabet()->intToChar(state) + " is not allowed in model.");
   if (i == size_ - 1 && state == -1) return 1.;
   vector<int> states = getAlphabet()->getAlias(state);
-  for (unsigned int j = 0; j < states.size(); j++)
+  for (size_t j = 0; j < states.size(); j++)
     if ((int)i == states[j]) return 1.;
   return 0.;
 }
