@@ -54,6 +54,7 @@
 //From Seqlib:
 #include <Bpp/Seq/Alphabet/Alphabet.h>
 #include <Bpp/Seq/Container/SequenceContainer.h>
+#include "FrequenciesSet/FrequenciesSet.h"
 
 namespace bpp
 {
@@ -111,7 +112,8 @@ public:
  * where \f$P(t)\f$ is the matrix with all probabilities \f$P_{i,j}(t)\f$, and
  * \f$ r \f$ the rate.
  * For some models, the \f$P_{i,j}(t)\f$'s can be computed analytically.
- * For more complexe models, we need to use a eigen-decomposition of \f$Q\f$:
+ *
+ * For more complex models, we need to use a eigen-decomposition of \f$Q\f$:
  * \f[ Q = U^{-1} . D . U, \f]
  * where \f$D = diag(\lambda_i)\f$ is a diagonal matrix.
  * Hence
@@ -141,6 +143,53 @@ public:
  * U^{-1} . diag\left(r^2 \times \lambda_i^2 \times e^{r \times \lambda_i \times t}\right) . U
  * \f]
  *
+ *
+ * If Q is not symmetric, then the eigenvalue matrix D is block diagonal
+ * with the real eigenvalues in 1-by-1 blocks and any complex eigenvalues,
+ * a + i*b, in 2-by-2 blocks, [a, b; -b, a].  That is, if the complex
+ * eigenvalues look like
+ * <pre>
+ * 
+ *           a + ib   .        .    .
+ *           .        a - ib   .    .
+ *           .        .        x    .
+ *           .        .        .    y
+ * </pre>
+ * then D looks like
+ * <pre>
+ * 
+ *           a          b      .    .
+ *          -b          a      .    .
+ *           .          .      x    .
+ *           .          .      .    y
+ * </pre>
+ *
+ * and exp(tD) equals
+ * <pre>
+ * 
+ *           exp(ta)cos(tb)   exp(ta)sin(tb)  .        .
+ *          -exp(ta)sin(tb)   exp(ta)cos(tb)  .        . 
+ *           .                .               exp(tx)  .
+ *           .                .               .        exp(ty)
+ * </pre>
+ *
+ *
+ *
+ * If U is singular, it cannot be inverted. In this case exp(tQ) is
+ * approximated using Taylor decomposition:
+ *
+ * \f[
+ * P(t) = Id + tQ + \frac{(tQ)^2}{2!} + ... + \frac{(tQ)^n}{n!} + ... 
+ * \f]
+ *
+ * To prevent approximation issues, if @\f$ max(tQ) @\f$ is too high
+ * (currently above 0.5), @\f$ t @\f$ is divided in an ad hoc way
+ * (e.g. by @\f$ N @\f$), and we compute @\f$ P(t) = (P(t/N))^N @\f$
+ * with a Taylor decomposition for @\f$ P(t/N) @\f$.
+ *
+ * In this case, derivatives according to @\f$ t @\f$ are computed
+ * analytically too.
+ *
  */
 
 class SubstitutionModel :
@@ -178,7 +227,7 @@ public:
    * @see MarkovModulatedSubstitutionModel
    * @see getStates()
    */
-  virtual int getAlphabetChar(unsigned int i) const = 0;
+  virtual int getAlphabetChar(size_t i) const = 0;
 
   /**
    * @brief Get the state in the model corresponding to a particular char in the alphabet.
@@ -186,40 +235,40 @@ public:
    * @param i The alphabet char to check.
    * @return A vector of indices of model states.
    */
-  virtual std::vector<unsigned int> getModelStates(int i) const = 0;
+  virtual std::vector<size_t> getModelStates(int i) const = 0;
 
   /**
    * @return Equilibrium frequency associated to character i.
    * @see getFrequencies(), getStates()
    */
-  virtual double freq(unsigned int i) const = 0;
+  virtual double freq(size_t i) const = 0;
 
   /**
    * @return The rate in the generator of change from state i to state j.
    *
    * @see getStates();
    */
-  virtual double Qij(unsigned int i, unsigned int j) const = 0;
+  virtual double Qij(size_t i, size_t j) const = 0;
 
   /**
    * @return The probability of change from state i to state j during time t.
    * @see getPij_t(), getStates()
    */
-  virtual double Pij_t(unsigned int i, unsigned int j, double t) const = 0;
+  virtual double Pij_t(size_t i, size_t j, double t) const = 0;
 
   /**
    * @return The first order derivative of the probability of change from state
    * i to state j with respect to time t, at time t.
    * @see getdPij_dt(), getStates()
    */
-  virtual double dPij_dt(unsigned int i, unsigned int j, double t) const = 0;
+  virtual double dPij_dt(size_t i, size_t j, double t) const = 0;
 
   /**
    * @return The second order derivative of the probability of change from state
    * i to state j with respect to time t, at time t.
    * @see getd2Pij_dt2(), getStates()
    */
-  virtual double d2Pij_dt2(unsigned int i, unsigned int j, double t) const = 0;
+  virtual double d2Pij_dt2(size_t i, size_t j, double t) const = 0;
 
   /**
    * @return A vector of all equilibrium frequencies.
@@ -244,6 +293,20 @@ public:
    */
   virtual const Matrix<double>& getGenerator() const = 0;
 
+  /**
+   * @return The matrix of exchangeability terms.
+   * It is recommended that exchangeability matrix be normalized so that the normalized
+   * generator be obtained directly by the dot product \f$S . \pi\f$.
+   */
+  virtual const Matrix<double>& getExchangeabilityMatrix() const = 0;
+
+  /**
+   * @return The exchangeability between state i and state j.
+   *
+   * By definition Sij(i,j) = Sij(j,i).
+   */
+  
+  virtual double Sij(size_t i, size_t j) const = 0;
   /**
    * @return All probabilities of change from state i to state j during time t.
    * @see Pij_t()
@@ -282,14 +345,17 @@ public:
   /**
    * @return A vector with all imaginary parts of the eigen values of the generator of this model;
    */
-  
   virtual const Vdouble& getIEigenValues() const = 0;
 
   /**
-   * @return if the model is diagonalizable in R.
+   * @return True if the model is diagonalizable in R.
    */
-
   virtual bool isDiagonalizable() const = 0;
+  
+  /**
+   * @return True is the model is non-singular.
+   */
+  virtual bool isNonSingular() const = 0;
 
   /**
    * @return A matrix with left eigen vectors.
@@ -315,7 +381,7 @@ public:
    *
    * @return The number of different states in the model.
    */
-  virtual unsigned int getNumberOfStates() const = 0;
+  virtual size_t getNumberOfStates() const = 0;
 
   /**
    * This method is used to initialize likelihoods in reccursions.
@@ -326,15 +392,36 @@ public:
    * @param i the index of the state in the model.
    * @param state An observed state in the sequence/site.
    * @return 1 or 0 depending if the two states are compatible.
+   * @throw IndexOutOfBoundsException if array position is out of range.
    * @throw BadIntException if states are not allowed in the associated alphabet.
    * @see getStates();
    */
-  virtual double getInitValue(unsigned int i, int state) const throw (BadIntException) = 0;
+  virtual double getInitValue(size_t i, int state) const throw (IndexOutOfBoundsException, BadIntException) = 0;
+
+  /**
+   * @brief Get the scalar product of diagonal elements of the generator
+   * and the frequencies vector.
+   * If the generator is normalized, then scale=1. Otherwise each element
+   * must be multiplied by 1/scale.
+   *
+   * @return Minus the scalar product of diagonal elements and the frequencies vector.
+   */
+  virtual double getScale() const = 0;
+
+  /**
+   * @brief Set the rate of the generator, defined as the scalar
+   * product of diagonal elements of the generator and the frequencies
+   * vector.
+   *
+   * When the generator is normalized, scale=1. Otherwise each element
+   * is multiplied such that the correct scale is set.
+   *
+   */
+  virtual void setScale(double scale) = 0;
 
   /**
    * @brief Get the rate
    */
-  
   virtual double getRate() const = 0;
 
   /**
@@ -358,7 +445,7 @@ public:
    * \pi_i = \frac{n_i+\psi}{\sum_j (f_j+\psi)}
    * @f]
    */
-  virtual void setFreqFromData(const SequenceContainer& data, unsigned int pseudoCount = 0) = 0;
+  virtual void setFreqFromData(const SequenceContainer& data, double pseudoCount = 0) = 0;
 
   /**
    * @brief Set equilibrium frequencies
@@ -366,6 +453,14 @@ public:
    * @param frequencies The map of the frequencies to use.
    */
   virtual void setFreq(std::map<int, double>& frequencies) {}
+
+  /**
+   * @brief If the model owns a FrequenciesSet, returns a pointer to
+   * it, otherwise return 0.
+   *
+   */
+
+  virtual const FrequenciesSet* getFrequenciesSet() const {return NULL;}
 };
 
 
@@ -390,21 +485,6 @@ public:
 #ifndef NO_VIRTUAL_COV
   ReversibleSubstitutionModel* clone() const = 0;
 #endif
-
-public:
-  /**
-   * @return The matrix of exchangeability terms.
-   * It is recommended that exchangeability matrix be normalized so that the normalized
-   * generator be obtained directly by the dot product \f$S . \pi\f$.
-   */
-  virtual const Matrix<double>& getExchangeabilityMatrix() const = 0;
-
-  /**
-   * @return The exchangeability between state i and state j.
-   *
-   * By definition Sij(i,j) = Sij(j,i).
-   */
-  virtual double Sij(unsigned int i, unsigned int j) const = 0;
 };
 
 } //end of namespace bpp.
