@@ -46,9 +46,14 @@
 
 #include <Bpp/App/ApplicationTools.h>
 #include <Bpp/Numeric/ParameterList.h>
-#include <Bpp/Numeric/Function.all>
+#include <Bpp/Numeric/Function/BfgsMultiDimensions.h>
+#include <Bpp/Numeric/Function/ReparametrizationFunctionWrapper.h>
+#include <Bpp/Numeric/Function/ThreePointsNumericalDerivative.h>
+#include <Bpp/Numeric/Function/ConjugateGradientMultiDimensions.h>
+#include <Bpp/Numeric/Function/TwoPointsNumericalDerivative.h>
+#include <Bpp/Numeric/Function/DownhillSimplexMethod.h>
 
-// From SeqLib:
+// From bpp-seq:
 #include <Bpp/Seq/Io/Fasta.h>
 
 using namespace bpp;
@@ -312,8 +317,7 @@ throw (Exception)
     throw Exception("OptimizationTools::optimizeNumericalParameters2. Unknown optimization method: " + optMethodDeriv);
 
   // Numerical derivatives:
-  ParameterList tmp = parameters.getCommonParametersWith(tl->getSubstitutionModelParameters());
-  tmp.addParameters(parameters.getCommonParametersWith(tl->getRateDistributionParameters()));
+  ParameterList tmp = tl->getNonDerivableParameters(); 
   if (useClock)
     tmp.addParameters(fclock->getHeightParameters());
   fnum->setParametersToDerivate(tmp.getParameterNames());
@@ -640,12 +644,41 @@ std::string OptimizationTools::DISTANCEMETHOD_ITERATIONS = "iterations";
 
 /******************************************************************************/
 
+DistanceMatrix* OptimizationTools::estimateDistanceMatrix(
+  DistanceEstimation& estimationMethod,
+  const ParameterList& parametersToIgnore,
+  const std::string& param,
+  unsigned int verbose) throw (Exception)
+{
+  if (param != DISTANCEMETHOD_PAIRWISE && param != DISTANCEMETHOD_INIT)
+    throw Exception("OptimizationTools::estimateDistanceMatrix. Invalid option param=" + param + ".");
+  estimationMethod.resetAdditionalParameters();
+  estimationMethod.setVerbose(verbose);
+  if (param == DISTANCEMETHOD_PAIRWISE)
+  {
+    ParameterList tmp = estimationMethod.getSubstitutionModel().getIndependentParameters();
+    tmp.addParameters(estimationMethod.getRateDistribution().getIndependentParameters());
+    tmp.deleteParameters(parametersToIgnore.getParameterNames());
+    estimationMethod.setAdditionalParameters(tmp);
+  }
+  // Compute matrice:
+  if (verbose > 0)
+    ApplicationTools::displayTask("Estimating distance matrix", true);
+  estimationMethod.computeMatrix();
+  auto_ptr<DistanceMatrix> matrix(estimationMethod.getMatrix());
+  if (verbose > 0)
+    ApplicationTools::displayTaskDone();
+
+  return matrix.release();
+}
+
+/******************************************************************************/
+
 TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
   DistanceEstimation& estimationMethod,
   AgglomerativeDistanceMethod& reconstructionMethod,
   const ParameterList& parametersToIgnore,
   bool optimizeBrLen,
-  bool rooted,
   const std::string& param,
   double tolerance,
   unsigned int tlEvalMax,
@@ -657,8 +690,8 @@ TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
   estimationMethod.setVerbose(verbose);
   if (param == DISTANCEMETHOD_PAIRWISE)
   {
-    ParameterList tmp = estimationMethod.getModel()->getIndependentParameters();
-    tmp.addParameters(estimationMethod.getRateDistribution()->getIndependentParameters());
+    ParameterList tmp = estimationMethod.getSubstitutionModel().getIndependentParameters();
+    tmp.addParameters(estimationMethod.getRateDistribution().getIndependentParameters());
     tmp.deleteParameters(parametersToIgnore.getParameterNames());
     estimationMethod.setAdditionalParameters(tmp);
   }
@@ -679,7 +712,7 @@ TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
     if (verbose > 0)
       ApplicationTools::displayTask("Building tree");
     reconstructionMethod.setDistanceMatrix(*matrix);
-    reconstructionMethod.computeTree(rooted);
+    reconstructionMethod.computeTree();
     previousTree = tree;
     delete matrix;
     tree = dynamic_cast<TreeTemplate<Node>*>(reconstructionMethod.getTree());
@@ -696,7 +729,13 @@ TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
       break;  // Ends here.
 
     // Now, re-estimate parameters:
-    DRHomogeneousTreeLikelihood tl(*tree, *estimationMethod.getData(), estimationMethod.getModel(), estimationMethod.getRateDistribution(), true, verbose > 1);
+    auto_ptr<SubstitutionModel> model(estimationMethod.getSubstitutionModel().clone());
+    auto_ptr<DiscreteDistribution> rdist(estimationMethod.getRateDistribution().clone());
+    DRHomogeneousTreeLikelihood tl(*tree,
+        *estimationMethod.getData(),
+        model.get(),
+        rdist.get(),
+        true, verbose > 1);
     tl.initialize();
     ParameterList parameters = tl.getParameters();
     if (!optimizeBrLen)
