@@ -5,7 +5,7 @@
 //
 
 /*
-   Copyright or © or Copr. CNRS, (November 16, 2004)
+   Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)
 
    This software is a computer program whose purpose is to provide classes
    for phylogenetic data analysis.
@@ -47,7 +47,7 @@
 #include "Parsimony/DRTreeParsimonyScore.h"
 #include "TreeTemplate.h"
 #include "Distance/DistanceEstimation.h"
-#include "Distance/AgglomerativeDistanceMethod.h"
+#include "Distance/DistanceMethod.h"
 
 #include <Bpp/Io/OutputStream.h>
 #include <Bpp/App/ApplicationTools.h>
@@ -537,8 +537,8 @@ public:
     {
       return lambda_.getParameter(name).getValue();
     }
-    unsigned int getNumberOfParameters() const { return 1; }
-    unsigned int getNumberOfIndependentParameters() const { return 1; }
+    size_t getNumberOfParameters() const { return 1; }
+    size_t getNumberOfIndependentParameters() const { return 1; }
   };
 
 public:
@@ -701,6 +701,28 @@ public:
     DRTreeParsimonyScore* tp,
     unsigned int verbose = 1);
 
+  /**
+   * @brief Estimate a distance matrix using maximum likelihood.
+   *
+   * This method estimate a distance matrix using a DistanceEstimation object.
+   * The main issue here is to estimate non-branch lengths parameters, as substitution model and rate distribution parameters.
+   * Twoe options are provideed here:
+   * - DISTANCEMETHOD_INIT (default) keep parameters to there initial value,
+   * - DISTANCEMETHOD_PAIRWISE estimated parameters in a pairwise manner, which is standard but not that satisfying...
+   *
+   * @param estimationMethod The distance estimation object to use.
+   * @param parametersToIgnore A list of parameters to ignore while optimizing parameters.
+   * @param param String describing the type of optimization to use.
+   * @param verbose Verbose level.
+   *
+   * @see buildDistanceTree for a procedure to jointly estimate the distance matrix and underlying tree.
+   */
+  static DistanceMatrix* estimateDistanceMatrix(
+    DistanceEstimation& estimationMethod,
+    const ParameterList& parametersToIgnore,
+    const std::string& param = DISTANCEMETHOD_INIT,
+    unsigned int verbose = 0) throw (Exception);
+
   /**
    * @brief Build a tree using a distance method.
    *
@@ -708,7 +730,7 @@ public:
    * The main issue here is to estimate non-branch lengths parameters, as substitution model and rate distribution parameters.
    * Three options are provideed here:
    * - DISTANCEMETHOD_INIT (default) keep parameters to there initial value,
-   * - DISTANCEMETHOD_PAIRWISE estimated parameters in a pairwise manner, which is standard but not good at all...
+   * - DISTANCEMETHOD_PAIRWISE estimated parameters in a pairwise manner, which is standard but not that satisfying...
    * - DISTANCEMETHOD_ITERATIONS uses Ninio et al's iterative algorithm, which uses Maximum Likelihood to estimate these parameters, and then update the distance matrix.
    * Ninio M, Privman E, Pupko T, Friedman N.
    * Phylogeny reconstruction: increasing the accuracy of pairwise distance estimation using Bayesian inference of evolutionary rates.
@@ -718,7 +740,6 @@ public:
    * @param reconstructionMethod The tree reconstruction object to use.
    * @param parametersToIgnore A list of parameters to ignore while optimizing parameters.
    * @param optimizeBrLen Tell if branch lengths should be optimized together with other parameters. This may lead to more accurate parameter estimation, but is slower.
-   * @param rooted Tell if rooted trees must be produced.
    * @param param String describing the type of optimization to use.
    * @param tolerance Threshold on likelihood for stopping the iterative procedure. Used only with param=DISTANCEMETHOD_ITERATIONS.
    * @param tlEvalMax Maximum number of likelihood computations to perform when optimizing parameters. Used only with param=DISTANCEMETHOD_ITERATIONS.
@@ -731,7 +752,6 @@ public:
     AgglomerativeDistanceMethod& reconstructionMethod,
     const ParameterList& parametersToIgnore,
     bool optimizeBrLen = false,
-    bool rooted = false,
     const std::string& param = DISTANCEMETHOD_INIT,
     double tolerance = 0.000001,
     unsigned int tlEvalMax = 1000000,
