@@ -54,6 +54,7 @@ using namespace bpp;
 // From the STL:
 #include <iostream>
 #include <sstream>
+#include <limits>
 
 using namespace std;
 
@@ -66,7 +67,7 @@ bool TreeTemplateTools::isMultifurcating(const Node& node)
   else
   {
     bool b = false;
-    for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+    for (size_t i = 0; i < node.getNumberOfSons(); i++)
     {
       b = b || isMultifurcating(*node.getSon(i));
     }
@@ -83,7 +84,7 @@ unsigned int TreeTemplateTools::getNumberOfLeaves(const Node& node)
   {
     nbLeaves++;
   }
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (int i = 0; i < static_cast<int>(node.getNumberOfSons()); i++)
   {
     nbLeaves += getNumberOfLeaves(*node[i]);
   }
@@ -95,7 +96,7 @@ unsigned int TreeTemplateTools::getNumberOfLeaves(const Node& node)
 unsigned int TreeTemplateTools::getNumberOfNodes(const Node& node)
 {
   unsigned int nbNodes = 1;
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (int i = 0; i < static_cast<int>(node.getNumberOfSons()); i++)
   {
     nbNodes += getNumberOfNodes(*node[i]);
   }
@@ -111,10 +112,10 @@ vector<string> TreeTemplateTools::getLeavesNames(const Node& node)
   {
     names.push_back(node.getName());
   }
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     vector<string> subNames = getLeavesNames(*node.getSon(i));
-    for (unsigned int j = 0; j < subNames.size(); j++)
+    for (size_t j = 0; j < subNames.size(); j++)
     {
       names.push_back(subNames[j]);
     }
@@ -127,7 +128,7 @@ vector<string> TreeTemplateTools::getLeavesNames(const Node& node)
 unsigned int TreeTemplateTools::getDepth(const Node& node)
 {
   unsigned int d = 0;
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (int i = 0; i < static_cast<int>(node.getNumberOfSons()); i++)
   {
     unsigned int c = getDepth(*node[i]) + 1;
     if (c > d)
@@ -141,7 +142,7 @@ unsigned int TreeTemplateTools::getDepth(const Node& node)
 unsigned int TreeTemplateTools::getDepths(const Node& node, map<const Node*, unsigned int>& depths)
 {
   unsigned int d = 0;
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (int i = 0; i < static_cast<int>(node.getNumberOfSons()); i++)
   {
     unsigned int c = getDepths(*node[i], depths) + 1;
     if (c > d)
@@ -156,7 +157,7 @@ unsigned int TreeTemplateTools::getDepths(const Node& node, map<const Node*, uns
 double TreeTemplateTools::getHeight(const Node& node)
 {
   double d = 0;
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (int i = 0; i < static_cast<int>(node.getNumberOfSons()); i++)
   {
     const Node* son = node[i];
     double dist = son->getDistanceToFather();
@@ -172,7 +173,7 @@ double TreeTemplateTools::getHeight(const Node& node)
 double TreeTemplateTools::getHeights(const Node& node, map<const Node*, double>& heights)
 {
   double d = 0;
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (int i = 0; i < static_cast<int>(node.getNumberOfSons()); i++)
   {
     const Node* son = node[i];
     double dist = son->getDistanceToFather();
@@ -193,7 +194,7 @@ TreeTemplateTools::Element TreeTemplateTools::getElement(const string& elt) thro
   element.bootstrap = ""; // default
   element.isLeaf    = false; // default
 
-  unsigned int colonIndex;
+  size_t colonIndex;
   bool hasColon = false;
   for (colonIndex = elt.size(); colonIndex > 0 && elt[colonIndex] != ')'; colonIndex--)
   {
@@ -210,7 +211,7 @@ TreeTemplateTools::Element TreeTemplateTools::getElement(const string& elt) thro
     {
       // this is an element with length:
       elt2 = elt.substr(0, colonIndex);
-      element.length = elt.substr(colonIndex + 1);
+      element.length = TextTools::removeSurroundingWhiteSpaces(elt.substr(colonIndex + 1));
     }
     else
     {
@@ -231,8 +232,8 @@ TreeTemplateTools::Element TreeTemplateTools::getElement(const string& elt) thro
       // This is a node:
       if (lastP < firstP)
         throw IOException("TreeTemplateTools::getElement(). Invalid format: bad closing parenthesis in " + elt2);
-      element.content = elt2.substr(firstP + 1, lastP - firstP - 1);
-      string bootstrap = elt2.substr(lastP + 1);
+      element.content = TextTools::removeSurroundingWhiteSpaces(elt2.substr(firstP + 1, lastP - firstP - 1));
+      string bootstrap = TextTools::removeSurroundingWhiteSpaces(elt2.substr(lastP + 1));
       // cout << "ELEMENT: BOOTSTRAP: " << bootstrap << endl;
       if (!TextTools::isEmpty(bootstrap))
       {
@@ -316,7 +317,7 @@ Node* TreeTemplateTools::parenthesisToNode(const string& description, bool boots
   else
   {
     // This is a node:
-    for (unsigned int i = 0; i < elements.size(); i++)
+    for (size_t i = 0; i < elements.size(); i++)
     {
       // cout << "NODE: SUBNODE: " << i << ", " << elements[i] << endl;
       Node* son = parenthesisToNode(elements[i], bootstrap, propertyName, withId);
@@ -357,7 +358,7 @@ string TreeTemplateTools::nodeToParenthesis(const Node& node, bool writeId)
   {
     s << "(";
     s << nodeToParenthesis(*node[0], writeId);
-    for (unsigned int i = 1; i < node.getNumberOfSons(); i++)
+    for (int i = 1; i < static_cast<int>(node.getNumberOfSons()); i++)
     {
       s << "," << nodeToParenthesis(*node[i], writeId);
     }
@@ -392,7 +393,7 @@ string TreeTemplateTools::nodeToParenthesis(const Node& node, bool bootstrap, co
   {
     s << "(";
     s << nodeToParenthesis(*node[0], bootstrap, propertyName);
-    for (unsigned int i = 1; i < node.getNumberOfSons(); i++)
+    for (int i = 1; i < static_cast<int>(node.getNumberOfSons()); i++)
     {
       s << "," << nodeToParenthesis(*node[i], bootstrap, propertyName);
     }
@@ -430,7 +431,7 @@ string TreeTemplateTools::treeToParenthesis(const TreeTemplate<Node>& tree, bool
   if (node->isLeaf() && node->hasName()) //In case we have a tree like ((A:1.0)); where the root node is an unamed leaf!
   {
     s << node->getName();
-    for (unsigned int i = 0; i < node->getNumberOfSons(); ++i)
+    for (size_t i = 0; i < node->getNumberOfSons(); ++i)
     {
       s << "," << nodeToParenthesis(*node->getSon(i), writeId);
     }
@@ -438,7 +439,7 @@ string TreeTemplateTools::treeToParenthesis(const TreeTemplate<Node>& tree, bool
   else
   {
     s << nodeToParenthesis(*node->getSon(0), writeId);
-    for (unsigned int i = 1; i < node->getNumberOfSons(); ++i)
+    for (size_t i = 1; i < node->getNumberOfSons(); ++i)
     {
       s << "," << nodeToParenthesis(*node->getSon(i), writeId);
     }
@@ -460,7 +461,7 @@ string TreeTemplateTools::treeToParenthesis(const TreeTemplate<Node>& tree, bool
   if (node->isLeaf())
   {
     s << node->getName();
-    for (unsigned int i = 0; i < node->getNumberOfSons(); i++)
+    for (size_t i = 0; i < node->getNumberOfSons(); i++)
     {
       s << "," << nodeToParenthesis(*node->getSon(i), bootstrap, propertyName);
     }
@@ -468,7 +469,7 @@ string TreeTemplateTools::treeToParenthesis(const TreeTemplate<Node>& tree, bool
   else
   {
     s << nodeToParenthesis(*node->getSon(0), bootstrap, propertyName);
-    for (unsigned int i = 1; i < node->getNumberOfSons(); i++)
+    for (size_t i = 1; i < node->getNumberOfSons(); i++)
     {
       s << "," << nodeToParenthesis(*node->getSon(i), bootstrap, propertyName);
     }
@@ -499,10 +500,10 @@ Vdouble TreeTemplateTools::getBranchLengths(const Node& node) throw (NodePExcept
 {
   Vdouble brLen(1);
   brLen[0] = node.getDistanceToFather();
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     Vdouble sonBrLen = getBranchLengths(*node.getSon(i));
-    for (unsigned int j = 0; j < sonBrLen.size(); j++)
+    for (size_t j = 0; j < sonBrLen.size(); j++)
     {
       brLen.push_back(sonBrLen[j]);
     }
@@ -517,7 +518,7 @@ double TreeTemplateTools::getTotalLength(const Node& node, bool includeAncestor)
   if (includeAncestor && !node.hasDistanceToFather())
     throw NodePException("TreeTools::getTotalLength(). No branch length.", &node);
   double length = includeAncestor ? node.getDistanceToFather() : 0;
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     length += getTotalLength(*node.getSon(i), true);
   }
@@ -529,7 +530,7 @@ double TreeTemplateTools::getTotalLength(const Node& node, bool includeAncestor)
 void TreeTemplateTools::setBranchLengths(Node& node, double brLen)
 {
   node.setDistanceToFather(brLen);
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     setBranchLengths(*node.getSon(i), brLen);
   }
@@ -540,7 +541,7 @@ void TreeTemplateTools::setBranchLengths(Node& node, double brLen)
 void TreeTemplateTools::deleteBranchLengths(Node& node)
 {
   node.deleteDistanceToFather();
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     deleteBranchLengths(*node.getSon(i));
   }
@@ -552,7 +553,7 @@ void TreeTemplateTools::setVoidBranchLengths(Node& node, double brLen)
 {
   if (!node.hasDistanceToFather())
     node.setDistanceToFather(brLen);
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     setVoidBranchLengths(*node.getSon(i), brLen);
   }
@@ -566,7 +567,7 @@ void TreeTemplateTools::scaleTree(Node& node, double factor) throw (NodePExcepti
   {
     node.setDistanceToFather(node.getDistanceToFather() * factor);
   }
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     scaleTree(*node.getSon(i), factor);
   }
@@ -583,7 +584,7 @@ TreeTemplate<Node>* TreeTemplateTools::getRandomTree(vector<string>& leavesNames
   // Att the end, contains only the root node of the tree.
   vector<Node*> nodes(leavesNames.size());
   // Create all leaves nodes:
-  for (unsigned int i = 0; i < leavesNames.size(); ++i)
+  for (size_t i = 0; i < leavesNames.size(); ++i)
   {
     nodes[i] = new Node(leavesNames[i]);
   }
@@ -591,10 +592,10 @@ TreeTemplate<Node>* TreeTemplateTools::getRandomTree(vector<string>& leavesNames
   while (nodes.size() > (rooted ? 2 : 3))
   {
     // Select random nodes:
-    int pos1 = RandomTools::giveIntRandomNumberBetweenZeroAndEntry(nodes.size());
+    int pos1 = RandomTools::giveIntRandomNumberBetweenZeroAndEntry(static_cast<int>(nodes.size()));
     Node* node1 = nodes[pos1];
     nodes.erase(nodes.begin() + pos1);
-    int pos2 = RandomTools::giveIntRandomNumberBetweenZeroAndEntry(nodes.size());
+    int pos2 = RandomTools::giveIntRandomNumberBetweenZeroAndEntry(static_cast<int>(nodes.size()));
     Node* node2 = nodes[pos2];
     nodes.erase(nodes.begin() + pos2);
     // Add new node:
@@ -639,25 +640,25 @@ vector<Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(Node& node1, Node& no
   pathMatrix2.push_back(nodeUp); // The root.
   // Must check that the two nodes have the same root!!!
 
-  int tmp1 = pathMatrix1.size() - 1;
-  int tmp2 = pathMatrix2.size() - 1;
+  size_t tmp1 = pathMatrix1.size() - 1;
+  size_t tmp2 = pathMatrix2.size() - 1;
 
-  while ((tmp1 >= 0) && (tmp2 >= 0))
+  while (pathMatrix1[tmp1] == pathMatrix2[tmp2]
+         and tmp1 > 0
+         and tmp2 > 0)
   {
-    if (pathMatrix1[tmp1] != pathMatrix2[tmp2])
-      break;
     tmp1--; tmp2--;
   }
 
-  for (int y = 0; y <= tmp1; ++y)
+  for (size_t y = 0; y < tmp1; ++y)
   {
     path.push_back(pathMatrix1[y]);
   }
   if (includeAncestor)
-    path.push_back(pathMatrix1[tmp1 + 1]);  // pushing once, the Node that was common to both.
-  for (int j = tmp2; j >= 0; --j)
+    path.push_back(pathMatrix1[tmp1]);  // pushing once, the Node that was common to both.
+  for (size_t j = tmp2; j > 0; --j)
   {
-    path.push_back(pathMatrix2[j]);
+    path.push_back(pathMatrix2[j - 1]);
   }
   return path;
 }
@@ -687,25 +688,25 @@ vector<const Node*> TreeTemplateTools::getPathBetweenAnyTwoNodes(const Node& nod
   pathMatrix2.push_back(nodeUp); // The root.
   // Must check that the two nodes have the same root!!!
 
-  int tmp1 = pathMatrix1.size() - 1;
-  int tmp2 = pathMatrix2.size() - 1;
+  size_t tmp1 = pathMatrix1.size() - 1;
+  size_t tmp2 = pathMatrix2.size() - 1;
 
-  while ((tmp1 >= 0) && (tmp2 >= 0))
+  while (pathMatrix1[tmp1] == pathMatrix2[tmp2]
+         and tmp1 > 0
+         and tmp2 > 0)
   {
-    if (pathMatrix1[tmp1] != pathMatrix2[tmp2])
-      break;
     tmp1--; tmp2--;
   }
 
-  for (int y = 0; y <= tmp1; ++y)
+  for (size_t y = 0; y < tmp1; ++y)
   {
     path.push_back(pathMatrix1[y]);
   }
   if (includeAncestor)
-    path.push_back(pathMatrix1[tmp1 + 1]);  // pushing once, the Node that was common to both.
-  for (int j = tmp2; j >= 0; --j)
+    path.push_back(pathMatrix1[tmp1]);  // pushing once, the Node that was common to both.
+  for (size_t j = tmp2; j > 0; --j)
   {
-    path.push_back(pathMatrix2[j]);
+    path.push_back(pathMatrix2[j - 1]);
   }
   return path;
 }
@@ -716,7 +717,7 @@ double TreeTemplateTools::getDistanceBetweenAnyTwoNodes(const Node& node1, const
 {
   vector<const Node*> path = getPathBetweenAnyTwoNodes(node1, node2, false);
   double d = 0;
-  for (unsigned int i = 0; i < path.size(); i++)
+  for (size_t i = 0; i < path.size(); i++)
   {
     d += path[i]->getDistanceToFather();
   }
@@ -739,7 +740,7 @@ void TreeTemplateTools::processDistsInSubtree_(const Node* node, DistanceMatrix&
   // For all leaves in node's subtree, get leaf-to-node distances.
   // Leaves are classified upon node's sons.
   map<const Node*, vector< pair<string, double> > > leavesDists;
-  for (unsigned int i = 0; i < node->getNumberOfSons(); ++i)
+  for (size_t i = 0; i < node->getNumberOfSons(); ++i)
   {
     const Node* son = node->getSon(i);
     processDistsInSubtree_(son, matrix, leavesDists[son]); // recursivity
@@ -747,9 +748,9 @@ void TreeTemplateTools::processDistsInSubtree_(const Node* node, DistanceMatrix&
   // Write leaf-leaf distances to the distance matrix.
   // Only pairs in which the two leaves belong to different
   // sons are considered.
-  for (unsigned int son1_loc = 0; son1_loc < node->getNumberOfSons(); ++son1_loc)
+  for (size_t son1_loc = 0; son1_loc < node->getNumberOfSons(); ++son1_loc)
   {
-    for (unsigned int son2_loc = 0; son2_loc < son1_loc; ++son2_loc)
+    for (size_t son2_loc = 0; son2_loc < son1_loc; ++son2_loc)
     {
       const Node* son1 = node->getSon(son1_loc);
       const Node* son2 = node->getSon(son2_loc);
@@ -814,7 +815,7 @@ std::vector<const Node*> TreeTemplateTools::getRemainingNeighbors(const Node* no
 {
   vector<const Node*> neighbors = node1->getNeighbors();
   vector<const Node*> neighbors2;
-  for (unsigned int k = 0; k < neighbors.size(); k++)
+  for (size_t k = 0; k < neighbors.size(); k++)
   {
     const Node* n = neighbors[k];
     if (n != node2 && n != node3)
@@ -828,7 +829,7 @@ std::vector<const Node*> TreeTemplateTools::getRemainingNeighbors(const Node* no
 void TreeTemplateTools::incrementAllIds(Node* node, int increment)
 {
   node->setId(node->getId() + increment);
-  for (unsigned int i = 0; i < node->getNumberOfSons(); i++)
+  for (size_t i = 0; i < node->getNumberOfSons(); i++)
   {
     incrementAllIds(node->getSon(i), increment);
   }
@@ -839,7 +840,7 @@ void TreeTemplateTools::incrementAllIds(Node* node, int increment)
 void TreeTemplateTools::getNodePropertyNames(const Node& node, vector<string>& propertyNames)
 {
   VectorTools::extend(propertyNames, node.getNodePropertyNames());
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     getNodePropertyNames(*node.getSon(i), propertyNames);
   }
@@ -849,7 +850,7 @@ void TreeTemplateTools::getNodeProperties(const Node& node, const string& proper
 {
   if (node.hasNodeProperty(propertyName))
     properties[node.getId()] = node.getNodeProperty(propertyName);
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     getNodeProperties(*node.getSon(i), propertyName, properties);
   }
@@ -859,7 +860,7 @@ void TreeTemplateTools::getNodeProperties(Node& node, const string& propertyName
 {
   if (node.hasNodeProperty(propertyName))
     properties[node.getId()] = node.getNodeProperty(propertyName);
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     getNodeProperties(*node.getSon(i), propertyName, properties);
   }
@@ -870,7 +871,7 @@ void TreeTemplateTools::getNodeProperties(Node& node, const string& propertyName
 void TreeTemplateTools::getBranchPropertyNames(const Node& node, vector<string>& propertyNames)
 {
   VectorTools::extend(propertyNames, node.getBranchPropertyNames());
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     getBranchPropertyNames(*node.getSon(i), propertyNames);
   }
@@ -880,7 +881,7 @@ void TreeTemplateTools::getBranchProperties(const Node& node, const string& prop
 {
   if (node.hasBranchProperty(propertyName))
     properties[node.getId()] = node.getBranchProperty(propertyName);
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     getBranchProperties(*node.getSon(i), propertyName, properties);
   }
@@ -890,7 +891,7 @@ void TreeTemplateTools::getBranchProperties(Node& node, const string& propertyNa
 {
   if (node.hasBranchProperty(propertyName))
     properties[node.getId()] = node.getBranchProperty(propertyName);
-  for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+  for (size_t i = 0; i < node.getNumberOfSons(); i++)
   {
     getBranchProperties(*node.getSon(i), propertyName, properties);
   }
@@ -902,13 +903,13 @@ bool TreeTemplateTools::haveSameOrderedTopology(const Node& n1, const Node& n2)
 {
   if (n1.isLeaf() && n2.isLeaf() && n1.getName() != n2.getName())
     return false;
-  unsigned int nl1 = n1.getNumberOfSons();
-  unsigned int nl2 = n2.getNumberOfSons();
+  size_t nl1 = n1.getNumberOfSons();
+  size_t nl2 = n2.getNumberOfSons();
   if (nl1 != nl2)
     return false;
 
   bool test = true;
-  for (unsigned int i = 0; test && i < n1.getNumberOfSons(); ++i)
+  for (size_t i = 0; test && i < n1.getNumberOfSons(); ++i)
   {
     test &= haveSameOrderedTopology(*n1.getSon(i), *n2.getSon(i));
   }
@@ -928,9 +929,9 @@ TreeTemplateTools::OrderTreeData_ TreeTemplateTools::orderTree_(Node& node, bool
   }
   else
   {
-    vector<unsigned int> nbSons;
+    vector<size_t> nbSons;
     vector<string> firstLeaves;
-    for (unsigned int i = 0; i < node.getNumberOfSons(); i++)
+    for (size_t i = 0; i < node.getNumberOfSons(); i++)
     {
       OrderTreeData_ otdsub = orderTree_(*node.getSon(i), downward, orderLeaves);
       if (i == 0)
@@ -1007,3 +1008,180 @@ TreeTemplateTools::OrderTreeData_ TreeTemplateTools::orderTree_(Node& node, bool
 
 /******************************************************************************/
 
+void TreeTemplateTools::midRoot (TreeTemplate<Node>& tree, const string& criterion)
+{
+  if(not (criterion == "variance" || "sum of squares"))
+    throw Exception("TreeTemplateTools::reRoot Illegal criterion value '" + criterion + "'");
+
+  if(tree.isRooted())
+    tree.unroot();
+  Node* ref_root = tree.getRootNode();
+   /*
+   * The bestRoot object records :
+   * -- the current best branch : .first
+   * -- the current best value of the criterion : .second["value"]
+   * -- the best position of the root on the branch : .second["position"]
+   *      0 is toward the original root, 1 is away from it
+   */
+  pair<Node*, map<string, double> > best_root_branch;
+  best_root_branch.first = ref_root; // nota: the root does not correspond to a branch as it has no father
+  best_root_branch.second ["position"] = -1;
+  best_root_branch.second ["score"] = numeric_limits<double>::max();
+
+  // find the best root
+  TreeTemplateTools::getBestRootInSubtree(tree, criterion, ref_root, best_root_branch);
+  tree.rootAt(ref_root); // back to the original root
+
+  // reroot
+  const double pos = best_root_branch.second["position"];
+  if(pos<1e-6 or pos>1-1e-6)
+    // The best root position is on a node (this is often the case with the sum of squares criterion)
+    tree.rootAt(pos<1e-6 ? best_root_branch.first->getFather() : best_root_branch.first);
+  else
+    // The best root position is somewhere on a branch (a new Node is created)
+    {
+    Node* new_root = new Node();
+    new_root->setId( TreeTools::getMPNUId(tree, tree.getRootId()) );
+
+    double root_branch_length = best_root_branch.first->getDistanceToFather();
+    Node* best_root_father = best_root_branch.first->getFather();
+
+    best_root_father->removeSon(best_root_branch.first);
+    best_root_father->addSon(new_root);
+    new_root->addSon(best_root_branch.first);
+
+    new_root->setDistanceToFather(max(pos * root_branch_length, 1e-6));
+    best_root_branch.first->setDistanceToFather(max((1-pos) * root_branch_length, 1e-6));
+
+    // The two branches leaving the root must have the same branch properties
+    const vector<string> branch_properties = best_root_branch.first->getBranchPropertyNames();
+    for(vector<string>::const_iterator p = branch_properties.begin(); p!=branch_properties.end(); ++p)
+      new_root->setBranchProperty(*p, *best_root_branch.first->getBranchProperty(*p));
+
+    tree.rootAt(new_root);
+    }
+}
+
+/******************************************************************************/
+
+double TreeTemplateTools::getRadius (TreeTemplate<Node>& tree)
+{
+  TreeTemplateTools::midRoot(tree, "sum of squares");
+  Moments_ moments = getSubtreeMoments(tree.getRootNode());
+  double radius = moments.sum / moments.numberOfLeaves;
+  return radius;
+}
+
+/******************************************************************************/
+
+void TreeTemplateTools::getBestRootInSubtree (TreeTemplate<Node>& tree, const string& criterion, Node* node, pair<Node*, map<string, double> >& bestRoot)
+{
+  const vector<Node*> sons = node->getSons(); // copy
+  tree.rootAt(node);
+
+  // Try to place the root on each branch downward node
+  for(vector<Node*>::const_iterator son=sons.begin(); son!=sons.end(); ++son)
+    {
+    // Compute the moment of the subtree on son's side
+    Moments_ son_moment = getSubtreeMoments(*son);
+
+    // Compute the moment of the subtree on node's side
+    tree.rootAt(*son);
+    Moments_ node_moment = getSubtreeMoments(node);
+    tree.rootAt(node);
+
+    /*
+     * Get the position of the root on this branch that
+     * minimizes the root-to-leaves distances variance.
+     *
+     * This variance can be written in the form A x^2 + B x + C
+     */
+    double min_criterion_value;
+    double best_position; // 0 is toward the root, 1 is away from it
+
+    const TreeTemplateTools::Moments_& m1 = node_moment;
+    const TreeTemplateTools::Moments_& m2 = son_moment;
+    const double d = (**son).getDistanceToFather();
+    const double n1 = m1.numberOfLeaves;
+    const double n2 = m2.numberOfLeaves;
+
+    double A=0, B=0, C=0;
+    if(criterion == "sum of squares")
+      {
+      A = (n1 + n2) * d * d;
+      B = 2 * d * (m1.sum - m2.sum) - 2 * n2 * d * d;
+      C = m1.squaresSum + m2.squaresSum
+          + 2 * m2.sum * d
+          + n2 * d * d;
+      }
+    else if(criterion == "variance")
+      {
+      A = 4 * n1 * n2 * d*d;
+      B = 4 * d * ( n2 * m1.sum - n1 * m2.sum - d * n1 * n2);
+      C = (n1 + n2) * (m1.squaresSum + m2.squaresSum) + n1 * d * n2 * d
+          + 2 * n1 * d * m2.sum - 2 * n2 * d * m1.sum
+          - (m1.sum + m2.sum) * (m1.sum + m2.sum);
+      }
+
+    if(A < 1e-20)
+      {
+      min_criterion_value = numeric_limits<double>::max();
+      best_position = 0.5;
+      }
+    else
+      {
+      min_criterion_value = C - B*B / (4*A);
+      best_position = - B / (2*A);
+      if(best_position < 0)
+        {
+        best_position = 0;
+        min_criterion_value = C;
+        }
+      else if(best_position > 1)
+        {
+        best_position = 1;
+        min_criterion_value = A+B+C;
+        }
+      }
+
+    // Is this branch is the best seen, update 'bestRoot'
+    if(min_criterion_value < bestRoot.second["score"])
+      {
+      bestRoot.first = *son;
+      bestRoot.second["position"] = best_position;
+      bestRoot.second["score"] = min_criterion_value;
+      }
+
+    // Recurse
+    TreeTemplateTools::getBestRootInSubtree(tree, criterion, *son, bestRoot);
+    }
+}
+
+/******************************************************************************/
+
+TreeTemplateTools::Moments_ TreeTemplateTools::getSubtreeMoments (const Node* node)
+{
+  TreeTemplateTools::Moments_ moments = {0,0,0};
+
+  if(node->isLeaf())
+    {
+    moments.numberOfLeaves = 1;
+    }
+  else
+    {
+    const size_t nsons = node->getNumberOfSons();
+    for(size_t i=0; i<nsons; ++i)
+      {
+      const Node* son = node->getSon(i);
+      const TreeTemplateTools::Moments_ son_moments = TreeTemplateTools::getSubtreeMoments(son);
+      const double d = son->getDistanceToFather();
+      moments.numberOfLeaves += son_moments.numberOfLeaves;
+      moments.sum += son_moments.sum + d * son_moments.numberOfLeaves;
+      moments.squaresSum += son_moments.squaresSum + 2 * d * son_moments.sum + son_moments.numberOfLeaves * d*d;
+      }
+    }
+
+  return moments;
+}
+
+/******************************************************************************/
